"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QFileInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qfileinfo.html

    **Detailed Description**

    QFileInfo provides information about a file's name and position (path) in
    the file system, its access rights and whether it is a directory or symbolic
    link, etc. The file's size and last modified/read times are also available.
    QFileInfo can also be used to obtain information about a Qt **resource** .

    A QFileInfo can point to a file with either a relative or an absolute file
    path. Absolute file paths begin with the directory separator "/" (or with a
    drive specification on Windows). Relative file names begin with a directory
    name or a file name and specify a path relative to the current working
    directory. An example of an absolute path is the string "/tmp/quartz". A
    relative path might look like "src/fatlib". You can use the function
    **isRelative** () to check whether a QFileInfo is using a relative or an
    absolute file path. You can call the function **makeAbsolute** () to convert
    a relative QFileInfo's path to an absolute path.

    **Note:** Paths starting with a colon ( **:** ) are always considered
    absolute, as they denote a **QResource** .

    The file that the QFileInfo works on is set in the constructor or later with
    **setFile** (). Use **exists** () to see if the file exists and **size** ()
    to get its size.

    The file's type is obtained with **isFile** (), **isDir** () and
    **isSymLink** (). The **symLinkTarget** () function provides the name of the
    file the symlink points to.

    On Unix (including macOS and iOS), the property getter functions in this
    class return the properties such as times and size of the target file, not
    the symlink, because Unix handles symlinks transparently. Opening a symlink
    using **QFile**  effectively opens the link's target. For example:

    #ifdef Q_OS_UNIX

        QFileInfo info1("/home/bob/bin/untabify");
    info1.isSymLink();          // returns true
        info1.absoluteFilePath();
    // returns "/home/bob/bin/untabify"
        info1.size();               //
    returns 56201
        info1.symLinkTarget();      // returns
    "/opt/pretty++/bin/untabify"

        QFileInfo
    info2(info1.symLinkTarget());
        info2.isSymLink();          // returns
    false
        info2.absoluteFilePath();   // returns
    "/opt/pretty++/bin/untabify"
        info2.size();               // returns
    56201

        #endif

    On Windows, shortcuts (`.lnk` files) are currently treated as symlinks. As
    on Unix systems, the property getters return the size of the targeted file,
    not the `.lnk` file itself. This behavior is deprecated and will likely be
    removed in a future version of Qt, after which `.lnk` files will be treated
    as regular files.

    #ifdef Q_OS_WIN

        QFileInfo info1("C:\\\\Documents and
    Settings\\\\Bob\\\\untabify.lnk");
        info1.isSymLink();          // returns
    true
        info1.absoluteFilePath();   // returns "C:/Documents and
    Settings/Bob/untabify.lnk"
        info1.size();               // returns 743
    info1.symLinkTarget();      // returns "C:/Pretty++/untabify"
    QFileInfo info2(info1.symLinkTarget());
        info2.isSymLink();          //
    returns false
        info2.absoluteFilePath();   // returns
    "C:/Pretty++/untabify"
        info2.size();               // returns 63942
    #endif

    Elements of the file's name can be extracted with **path** () and
    **fileName** (). The **fileName** ()'s parts can be extracted with
    **baseName** (), **suffix** () or **completeSuffix** (). QFileInfo objects
    to directories created by Qt classes will not have a trailing file
    separator. If you wish to use trailing separators in your own file info
    objects, just append one to the file name given to the constructors or
    **setFile** ().

    The file's dates are returned by **birthTime** (), **lastModified** (),
    **lastRead** () and **fileTime** (). Information about the file's access
    permissions is obtained with **isReadable** (), **isWritable** () and
    **isExecutable** (). The file's ownership is available from **owner** (),
    **ownerId** (), **group** () and **groupId** (). You can examine a file's
    permissions and ownership in a single statement using the **permission** ()
    function.

    **Note:** On NTFS file systems, ownership and permissions checking is
    disabled by default for performance reasons. To enable it, include the
    following line:

    extern Q_CORE_EXPORT int qt_ntfs_permission_lookup;

    Permission checking is then turned on and off by incrementing and
    decrementing `qt_ntfs_permission_lookup` by 1.

    qt_ntfs_permission_lookup++; // turn checking on
    qt_ntfs_permission_lookup--; // turn it off again

    **Performance Issues**

    Some of QFileInfo's functions query the file system, but for performance
    reasons, some functions only operate on the file name itself. For example:
    To return the absolute path of a relative file name, **absolutePath** () has
    to query the file system. The **path** () function, however, can work on the
    file name directly, and so it is faster.

    **Note:** To speed up performance, QFileInfo caches information about the
    file.

    Because files can be changed by other users or programs, or even by other
    parts of the same program, there is a function that refreshes the file
    information: **refresh** (). If you want to switch off a QFileInfo's caching
    and force it to access the file system every time you request information
    from it call **setCaching** (false). If you want to make sure that all
    information is read from the file system, use **stat** ().

    **See also** **QDir**  and **QFile** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#QFileInfo-1

        **QFileInfo::QFileInfo()**

        Constructs an empty QFileInfo object.

        Note that an empty QFileInfo object contain no file reference.

        **See also** **setFile** ().
        """
        ...

    @typing.overload
    def __init__(self, file: QFileDevice) -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#QFileInfo-2

        **QFileInfo::QFileInfo(const QString & file )**

        Constructs a new QFileInfo that gives information about the given file.
        The **file** can also include an absolute or relative path.

        **See also** **setFile** (), **isRelative** (), **QDir::setCurrent** (),
        and **QDir::isRelativePath** ().
        """
        ...

    @typing.overload
    def __init__(self, file: str) -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#QFileInfo-3

        **QFileInfo::QFileInfo(const QFileDevice & file )**

        Constructs a new QFileInfo that gives information about file **file**.

        If the **file** has a relative path, the QFileInfo will also have a
        relative path.

        **See also** **isRelative** ().
        """
        ...

    @typing.overload
    def __init__(self, dir: QDir, file: str) -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#QFileInfo-4

        **QFileInfo::QFileInfo(const QDir & dir , const QString & file )**

        Constructs a new QFileInfo that gives information about the given
        **file** relative to the directory **dir**.

        If **dir** has a relative path, the QFileInfo will also have a relative
        path.

        If **file** is an absolute path, then the directory specified by **dir**
        will be disregarded.

        **See also** **isRelative** ().
        """
        ...

    @typing.overload
    def __init__(self, fileinfo: "QFileInfo") -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#QFileInfo-5

        **QFileInfo::QFileInfo(const QFileInfo & fileinfo )**

        Constructs a new QFileInfo that is a copy of the given **fileinfo**.
        """
        ...

    def junctionTarget(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#junctionTarget

        **[since 6.2] QString QFileInfo::junctionTarget() const**

        Resolves an NTFS junction to the path it references.

        Returns the absolute path to the directory an NTFS junction points to,
        or an empty string if the object is not an NTFS junction.

        There is no guarantee that the directory named by the NTFS junction
        actually exists.

        This function was introduced in Qt 6.2.

        **See also** **isJunction** (), **isFile** (), **isDir** (),
        **isSymLink** (), **isSymbolicLink** (), and **isShortcut** ().
        """
        ...

    def stat(self) -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#stat

        **[since 6.0] void QFileInfo::stat()**

        Reads all attributes from the file system.

        This is useful when information about the file system is collected in a
        worker thread, and then passed to the UI in the form of caching
        **QFileInfo**  instances.

        This function was introduced in Qt 6.0.

        **See also** **setCaching** () and **refresh** ().
        """
        ...

    def isJunction(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isJunction

        **[since 5.15] bool QFileInfo::isJunction() const**

        Returns `true` if the object points to a junction; otherwise returns
        `false`.

        Junctions only exist on Windows' NTFS file system, and are typically
        created by the `mklink` command. They can be thought of as symlinks for
        directories, and can only be created for absolute paths on the local
        volume.

        This function was introduced in Qt 5.15.
        """
        ...

    def isShortcut(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isShortcut

        **bool QFileInfo::isShortcut() const**

        Returns `true` if this object points to a shortcut; otherwise returns
        `false`.

        Shortcuts only exist on Windows and are typically `.lnk` files. For
        instance, true will be returned for shortcuts (`*.lnk` files) on
        Windows, but false will be returned on Unix (including macOS and iOS).

        The shortcut (.lnk) files are treated as regular files. Opening those
        will open the `.lnk` file itself. In order to open the file a shortcut
        references to, it must uses **symLinkTarget** () on a shortcut.

        **Note:** Even if a shortcut (broken shortcut) points to a non existing
        file, isShortcut() returns true.

        **See also** **isFile** (), **isDir** (), **isSymbolicLink** (), and
        **symLinkTarget** ().
        """
        ...

    def isSymbolicLink(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isSymbolicLink

        **bool QFileInfo::isSymbolicLink() const**

        Returns `true` if this object points to a symbolic link; otherwise
        returns `false`.

        Symbolic links exist on Unix (including macOS and iOS) and Windows
        (NTFS-symlink) and are typically created by the `ln -s` or `mklink`
        commands, respectively.

        Unix handles symlinks transparently. Opening a symbolic link effectively
        opens the **link's target** .

        In contrast to **isSymLink** (), false will be returned for shortcuts
        (`*.lnk` files) on Windows. Use **QFileInfo::isShortcut** () instead.

        **Note:** If the symlink points to a non existing file, **exists** ()
        returns false.

        **See also** **isFile** (), **isDir** (), **isShortcut** (), and
        **symLinkTarget** ().
        """
        ...

    def fileTime(self, time: QFileDevice.FileTime) -> QDateTime:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#fileTime

        **[since 5.10] QDateTime QFileInfo::fileTime(QFile::FileTime time )
        const**

        Returns the file time specified by **time**. If the time cannot be
        determined, an invalid date time is returned.

        If the file is a symlink, the time of the target file is returned (not
        the symlink).

        This function was introduced in Qt 5.10.

        **See also** **QFile::FileTime**  and **QDateTime::isValid** ().
        """
        ...

    def metadataChangeTime(self) -> QDateTime:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#metadataChangeTime

        **[since 5.10] QDateTime QFileInfo::metadataChangeTime() const**

        Returns the date and time when the file metadata was changed. A metadata
        change occurs when the file is created, but it also occurs whenever the
        user writes or sets inode information (for example, changing the file
        permissions).

        If the file is a symlink, the time of the target file is returned (not
        the symlink).

        This function was introduced in Qt 5.10.

        **See also** **lastModified** () and **lastRead** ().
        """
        ...

    def birthTime(self) -> QDateTime:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#birthTime

        **[since 5.10] QDateTime QFileInfo::birthTime() const**

        Returns the date and time when the file was created / born.

        If the file birth time is not available, this function returns an
        invalid **QDateTime** .

        If the file is a symlink, the time of the target file is returned (not
        the symlink).

        This function was introduced in Qt 5.10.

        **See also** **lastModified** (), **lastRead** (), and
        **metadataChangeTime** ().
        """
        ...

    def swap(self, other: "QFileInfo") -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#swap

        **[since 5.0] void QFileInfo::swap(QFileInfo & other )**

        Swaps this file info with **other**. This function is very fast and
        never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def isNativePath(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isNativePath

        **[since 5.0] bool QFileInfo::isNativePath() const**

        Returns `true` if the file path can be used directly with native APIs.
        Returns `false` if the file is otherwise supported by a virtual file
        system inside Qt, such as **the Qt Resource System** .

        **Note:** Native paths may still require conversion of path separators
        and character encoding, depending on platform and input requirements of
        the native API.

        This function was introduced in Qt 5.0.

        **See also** **QDir::toNativeSeparators** (), **QFile::encodeName** (),
        **filePath** (), **absoluteFilePath** (), and **canonicalFilePath** ().
        """
        ...

    def isBundle(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isBundle

        **bool QFileInfo::isBundle() const**

        Returns `true` if this object points to a bundle or to a symbolic link
        to a bundle on macOS and iOS; otherwise returns `false`.

        If the file is a symlink, this function returns true if the target is a
        bundle (not the symlink).

        **See also** **isDir** (), **isSymLink** (), and **isFile** ().
        """
        ...

    def bundleName(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#bundleName

        **QString QFileInfo::bundleName() const**

        Returns the name of the bundle.

        On macOS and iOS this returns the proper localized name for a bundle if
        the path **isBundle** (). On all other platforms an empty **QString**
        is returned.

        Example:

        QFileInfo fi("/Applications/Safari.app");
            **QString**  bundle =
        fi.bundleName();                // name = "Safari"

        **See also** **isBundle** (), **filePath** (), **baseName** (), and
        **suffix** ().
        """
        ...

    def symLinkTarget(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#symLinkTarget

        **QString QFileInfo::symLinkTarget() const**

        Returns the absolute path to the file or directory a symbolic link
        points to, or an empty string if the object isn't a symbolic link.

        This name may not represent an existing file; it is only a string.
        **QFileInfo::exists** () returns `true` if the symlink points to an
        existing file.

        **See also** **exists** (), **isSymLink** (), **isDir** (), and
        **isFile** ().
        """
        ...

    def setCaching(self, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#setCaching

        **void QFileInfo::setCaching(bool enable )**

        If **enable** is true, enables caching of file information. If
        **enable** is false caching is disabled.

        When caching is enabled, **QFileInfo**  reads the file information from
        the file system the first time it's needed, but generally not later.

        Caching is enabled by default.

        **See also** **refresh** () and **caching** ().
        """
        ...

    def caching(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#caching

        **bool QFileInfo::caching() const**

        Returns `true` if caching is enabled; otherwise returns `false`.

        **See also** **setCaching** () and **refresh** ().
        """
        ...

    def lastRead(self) -> QDateTime:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#lastRead

        **QDateTime QFileInfo::lastRead() const**

        Returns the date and local time when the file was last read (accessed).

        On platforms where this information is not available, returns the same
        as **lastModified** ().

        If the file is a symlink, the time of the target file is returned (not
        the symlink).

        **See also** **birthTime** (), **lastModified** (),
        **metadataChangeTime** (), and **fileTime** ().
        """
        ...

    def lastModified(self) -> QDateTime:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#lastModified

        **QDateTime QFileInfo::lastModified() const**

        Returns the date and local time when the file was last modified.

        If the file is a symlink, the time of the target file is returned (not
        the symlink).

        **See also** **birthTime** (), **lastRead** (), **metadataChangeTime**
        (), and **fileTime** ().
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#size

        **qint64 QFileInfo::size() const**

        Returns the file size in bytes. If the file does not exist or cannot be
        fetched, 0 is returned.

        If the file is a symlink, the size of the target file is returned (not
        the symlink).

        **See also** **exists** ().
        """
        ...

    def permissions(self) -> QFileDevice.Permission:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#permissions

        **QFile::Permissions QFileInfo::permissions() const**

        Returns the complete OR-ed together combination of QFile::Permissions
        for the file.

        **Note:** The result might be inaccurate on Windows if the **NTFS
        permissions**  check has not been enabled.

        If the file is a symlink, this function returns the permissions of the
        target (not the symlink).
        """
        ...

    def permission(self, permissions: QFileDevice.Permission) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#permission

        **bool QFileInfo::permission(QFile::Permissions permissions ) const**

        Tests for file permissions. The **permissions** argument can be several
        flags of type QFile::Permissions OR-ed together to check for permission
        combinations.

        On systems where files do not have permissions this function always
        returns `true`.

        **Note:** The result might be inaccurate on Windows if the **NTFS
        permissions**  check has not been enabled.

        Example:

        QFileInfo fi("/tmp/archive.tar.gz");
            if (fi.permission(**QFile**
        ::WriteUser | **QFile** ::ReadGroup))
                **qWarning** ("I can
        change the file; my group can read the file");
            if
        (fi.permission(**QFile** ::WriteGroup | **QFile** ::WriteOther))
        **qWarning** ("The group or others can change the file");

        If the file is a symlink, this function checks the permissions of the
        target (not the symlink).

        **See also** **isReadable** (), **isWritable** (), and **isExecutable**
        ().
        """
        ...

    def groupId(self) -> int:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#groupId

        **uint QFileInfo::groupId() const**

        Returns the id of the group the file belongs to.

        On Windows and on systems where files do not have groups this function
        always returns (uint) -2.

        If the file is a symlink, this function returns the id of the group
        owning the target (not the symlink).

        **See also** **group** (), **owner** (), and **ownerId** ().
        """
        ...

    def group(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#group

        **QString QFileInfo::group() const**

        Returns the group of the file. On Windows, on systems where files do not
        have groups, or if an error occurs, an empty string is returned.

        This function can be time consuming under Unix (in the order of
        milliseconds).

        If the file is a symlink, this function returns the owning group of the
        target (not the symlink).

        **See also** **groupId** (), **owner** (), and **ownerId** ().
        """
        ...

    def ownerId(self) -> int:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#ownerId

        **uint QFileInfo::ownerId() const**

        Returns the id of the owner of the file.

        On Windows and on systems where files do not have owners this function
        returns ((uint) -2).

        If the file is a symlink, this function returns the id of the owner of
        the target (not the symlink).

        **See also** **owner** (), **group** (), and **groupId** ().
        """
        ...

    def owner(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#owner

        **QString QFileInfo::owner() const**

        Returns the owner of the file. On systems where files do not have
        owners, or if an error occurs, an empty string is returned.

        This function can be time consuming under Unix (in the order of
        milliseconds). On Windows, it will return an empty string unless the
        **NTFS permissions**  check has been enabled.

        If the file is a symlink, this function returns the owner of the target
        (not the symlink).

        **See also** **ownerId** (), **group** (), and **groupId** ().
        """
        ...

    def isRoot(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isRoot

        **bool QFileInfo::isRoot() const**

        Returns `true` if the object points to a directory or to a symbolic link
        to a directory, and that directory is the root directory; otherwise
        returns `false`.
        """
        ...

    def isSymLink(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isSymLink

        **bool QFileInfo::isSymLink() const**

        Returns `true` if this object points to a symbolic link or shortcut;
        otherwise returns `false`.

        Symbolic links exist on Unix (including macOS and iOS) and Windows and
        are typically created by the `ln -s` or `mklink` commands, respectively.
        Opening a symbolic link effectively opens the **link's target** .

        In addition, true will be returned for shortcuts (`*.lnk` files) on
        Windows. This behavior is deprecated and will likely change in a future
        version of Qt. Opening those will open the `.lnk` file itself.

        Example:

        QFileInfo info(fileName);
            if (info.isSymLink())
                fileName =
        info.symLinkTarget();

        **Note:** If the symlink points to a non existing file, **exists** ()
        returns false.

        **See also** **isFile** (), **isDir** (), and **symLinkTarget** ().
        """
        ...

    def isDir(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isDir

        **bool QFileInfo::isDir() const**

        Returns `true` if this object points to a directory or to a symbolic
        link to a directory; otherwise returns `false`.

        If the file is a symlink, this function returns true if the target is a
        directory (not the symlink).

        **See also** **isFile** (), **isSymLink** (), and **isBundle** ().
        """
        ...

    def isFile(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isFile

        **bool QFileInfo::isFile() const**

        Returns `true` if this object points to a file or to a symbolic link to
        a file. Returns `false` if the object points to something which isn't a
        file, such as a directory.

        If the file is a symlink, this function returns true if the target is a
        regular file (not the symlink).

        **See also** **isDir** (), **isSymLink** (), and **isBundle** ().
        """
        ...

    def makeAbsolute(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#makeAbsolute

        **bool QFileInfo::makeAbsolute()**

        Converts the file's path to an absolute path if it is not already in
        that form. Returns `true` to indicate that the path was converted;
        otherwise returns `false` to indicate that the path was already
        absolute.

        **See also** **filePath** () and **isRelative** ().
        """
        ...

    def isAbsolute(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isAbsolute

        **bool QFileInfo::isAbsolute() const**

        Returns `true` if the file path is absolute, otherwise returns `false`
        (i.e. the path is relative).

        **Note:** Paths starting with a colon ( **:** ) are always considered
        absolute, as they denote a **QResource** .

        **See also** **isRelative** ().
        """
        ...

    def isRelative(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isRelative

        **bool QFileInfo::isRelative() const**

        Returns `true` if the file path is relative, otherwise returns `false`
        (i.e. the path is absolute). (E.g. under Unix a path is absolute if it
        begins with a "/").

        **Note:** Paths starting with a colon ( **:** ) are always considered
        absolute, as they denote a **QResource** .

        **See also** **isAbsolute** ().
        """
        ...

    def isHidden(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isHidden

        **bool QFileInfo::isHidden() const**

        Returns `true` if this is a `hidden' file; otherwise returns `false`.

        **Note:** This function returns `true` for the special entries "." and
        ".." on Unix, even though **QDir::entryList**  threats them as shown.
        And note that, since this function inspects the file name, on Unix it
        will inspect the name of the symlink, if this file is a symlink, not the
        target's name.

        On Windows, this function returns `true` if the target file is hidden
        (not the symlink).
        """
        ...

    def isExecutable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isExecutable

        **bool QFileInfo::isExecutable() const**

        Returns `true` if the file is executable; otherwise returns `false`.

        If the file is a symlink, this function returns true if the target is
        executable (not the symlink).

        **See also** **isReadable** (), **isWritable** (), and **permission**
        ().
        """
        ...

    def isWritable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isWritable

        **bool QFileInfo::isWritable() const**

        Returns `true` if the user can write to the file; otherwise returns
        `false`.

        If the file is a symlink, this function returns true if the target is
        writeable (not the symlink).

        **Note:** If the **NTFS permissions**  check has not been enabled, the
        result on Windows will merely reflect whether the file is marked as Read
        Only.

        **See also** **isReadable** (), **isExecutable** (), and **permission**
        ().
        """
        ...

    def isReadable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#isReadable

        **bool QFileInfo::isReadable() const**

        Returns `true` if the user can read the file; otherwise returns `false`.

        If the file is a symlink, this function returns true if the target is
        readable (not the symlink).

        **Note:** If the **NTFS permissions**  check has not been enabled, the
        result on Windows will merely reflect whether the file exists.

        **See also** **isWritable** (), **isExecutable** (), and **permission**
        ().
        """
        ...

    def absoluteDir(self) -> QDir:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#absoluteDir

        **QDir QFileInfo::absoluteDir() const**

        Returns the file's absolute path as a **QDir**  object.

        **See also** **dir** (), **filePath** (), **fileName** (), and
        **isRelative** ().
        """
        ...

    def dir(self) -> QDir:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#dir

        **QDir QFileInfo::dir() const**

        Returns the path of the object's parent directory as a **QDir**  object.

        **Note:** The **QDir**  returned always corresponds to the object's
        parent directory, even if the **QFileInfo**  represents a directory.

        For each of the following, dir() returns the **QDir**
        `"~/examples/191697"`.

        QFileInfo fileInfo1("~/examples/191697/.");
                QFileInfo
        fileInfo2("~/examples/191697/..");
                QFileInfo
        fileInfo3("~/examples/191697/main.cpp");

        For each of the following, dir() returns the **QDir**  `"."`.

        QFileInfo fileInfo4(".");
                QFileInfo fileInfo5("..");
        QFileInfo fileInfo6("main.cpp");

        **See also** **absolutePath** (), **filePath** (), **fileName** (),
        **isRelative** (), and **absoluteDir** ().
        """
        ...

    def canonicalPath(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#canonicalPath

        **QString QFileInfo::canonicalPath() const**

        Returns the file's path canonical path (excluding the file name), i.e.
        an absolute path without symbolic links or redundant "." or ".."
        elements.

        If the file does not exist, canonicalPath() returns an empty string.

        **See also** **path** () and **absolutePath** ().
        """
        ...

    def absolutePath(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#absolutePath

        **QString QFileInfo::absolutePath() const**

        Returns a file's path absolute path. This doesn't include the file name.

        On Unix the absolute path will always begin with the root, '/',
        directory. On Windows this will always begin 'D:/' where D is a drive
        letter, except for network shares that are not mapped to a drive letter,
        in which case the path will begin '//sharename/'.

        In contrast to **canonicalPath** () symbolic links or redundant "." or
        ".." elements are not necessarily removed.

        **Warning:** If **filePath** () is empty the behavior of this function
        is undefined.

        **See also** **absoluteFilePath** (), **path** (), **canonicalPath** (),
        **fileName** (), and **isRelative** ().
        """
        ...

    def path(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#path

        **QString QFileInfo::path() const**

        Returns the file's path. This doesn't include the file name.

        Note that, if this **QFileInfo**  object is given a path ending in a
        slash, the name of the file is considered empty and this function will
        return the entire path.

        **See also** **filePath** (), **absolutePath** (), **canonicalPath** (),
        **dir** (), **fileName** (), and **isRelative** ().
        """
        ...

    def completeSuffix(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#completeSuffix

        **QString QFileInfo::completeSuffix() const**

        Returns the complete suffix (extension) of the file.

        The complete suffix consists of all characters in the file after (but
        not including) the first '.'.

        Example:

        QFileInfo fi("/tmp/archive.tar.gz");
            **QString**  ext =
        fi.completeSuffix();  // ext = "tar.gz"

        **See also** **fileName** (), **suffix** (), **baseName** (), and
        **completeBaseName** ().
        """
        ...

    def suffix(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#suffix

        **QString QFileInfo::suffix() const**

        Returns the suffix (extension) of the file.

        The suffix consists of all characters in the file after (but not
        including) the last '.'.

        Example:

        QFileInfo fi("/tmp/archive.tar.gz");
            **QString**  ext = fi.suffix();
        // ext = "gz"

        The suffix of a file is computed equally on all platforms, independent
        of file naming conventions (e.g., ".bashrc" on Unix has an empty base
        name, and the suffix is "bashrc").

        **See also** **fileName** (), **completeSuffix** (), **baseName** (),
        and **completeBaseName** ().
        """
        ...

    def completeBaseName(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#completeBaseName

        **QString QFileInfo::completeBaseName() const**

        Returns the complete base name of the file without the path.

        The complete base name consists of all characters in the file up to (but
        not including) the **last** '.' character.

        Example:

        QFileInfo fi("/tmp/archive.tar.gz");
            **QString**  base =
        fi.completeBaseName();  // base = "archive.tar"

        **See also** **fileName** (), **suffix** (), **completeSuffix** (), and
        **baseName** ().
        """
        ...

    def baseName(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#baseName

        **QString QFileInfo::baseName() const**

        Returns the base name of the file without the path.

        The base name consists of all characters in the file up to (but not
        including) the **first** '.' character.

        Example:

        QFileInfo fi("/tmp/archive.tar.gz");
            **QString**  base =
        fi.baseName();  // base = "archive"

        The base name of a file is computed equally on all platforms,
        independent of file naming conventions (e.g., ".bashrc" on Unix has an
        empty base name, and the suffix is "bashrc").

        **See also** **fileName** (), **suffix** (), **completeSuffix** (), and
        **completeBaseName** ().
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#fileName

        **QString QFileInfo::fileName() const**

        Returns the name of the file, excluding the path.

        Example:

        QFileInfo fi("/tmp/archive.tar.gz");
            **QString**  name =
        fi.fileName();                // name = "archive.tar.gz"

        Note that, if this **QFileInfo**  object is given a path ending in a
        slash, the name of the file is considered empty.

        **See also** **isRelative** (), **filePath** (), **baseName** (), and
        **suffix** ().
        """
        ...

    def canonicalFilePath(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#canonicalFilePath

        **QString QFileInfo::canonicalFilePath() const**

        Returns the canonical path including the file name, i.e. an absolute
        path without symbolic links or redundant "." or ".." elements.

        If the file does not exist, canonicalFilePath() returns an empty string.

        **See also** **filePath** (), **absoluteFilePath** (), and **dir** ().
        """
        ...

    def absoluteFilePath(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#absoluteFilePath

        **QString QFileInfo::absoluteFilePath() const**

        Returns an absolute path including the file name.

        The absolute path name consists of the full path and the file name. On
        Unix this will always begin with the root, '/', directory. On Windows
        this will always begin 'D:/' where D is a drive letter, except for
        network shares that are not mapped to a drive letter, in which case the
        path will begin '//sharename/'. **QFileInfo**  will uppercase drive
        letters. Note that **QDir**  does not do this. The code snippet below
        shows this.

        QFileInfo fi("c:/temp/foo"); => fi.absoluteFilePath() => "C:/temp/foo"

        This function returns the same as **filePath** (), unless **isRelative**
        () is true. In contrast to **canonicalFilePath** (), symbolic links or
        redundant "." or ".." elements are not necessarily removed.

        **Warning:** If **filePath** () is empty the behavior of this function
        is undefined.

        **See also** **filePath** (), **canonicalFilePath** (), and
        **isRelative** ().
        """
        ...

    def __fspath__(self) -> typing.Any:
        ...

    def filePath(self) -> str:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#filePath

        **QString QFileInfo::filePath() const**

        Returns the file name, including the path (which may be absolute or
        relative).

        **See also** **absoluteFilePath** (), **canonicalFilePath** (), and
        **isRelative** ().
        """
        ...

    def refresh(self) -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#refresh

        **void QFileInfo::refresh()**

        Refreshes the information about the file, i.e. reads in information from
        the file system the next time a cached property is fetched.
        """
        ...

    @typing.overload
    def exists(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#exists

        **bool QFileInfo::exists() const**

        Returns `true` if the file exists; otherwise returns `false`.

        **Note:** If the file is a symlink that points to a non-existing file,
        false is returned.
        """
        ...

    @typing.overload
    @staticmethod
    def exists(file: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#exists-1

        **[static, since 5.2] bool QFileInfo::exists(const QString & file )**

        Returns `true` if the **file** exists; otherwise returns `false`.

        **Note:** If **file** is a symlink that points to a non-existing file,
        false is returned.

        **Note:** Using this function is faster than using
        `QFileInfo(file).exists()` for file system access.

        This function was introduced in Qt 5.2.
        """
        ...

    @typing.overload
    def setFile(self, file: str) -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#setFile

        **void QFileInfo::setFile(const QString & file )**

        Sets the file that the **QFileInfo**  provides information about to
        **file**.

        The **file** can also include an absolute or relative file path.
        Absolute paths begin with the directory separator (e.g. "/" under Unix)
        or a drive specification (under Windows). Relative file names begin with
        a directory name or a file name and specify a path relative to the
        current directory.

        Example:

        QFileInfo info("/usr/bin/env");

            **QString**  path =
        info.absolutePath(); // path = /usr/bin
            **QString**  base =
        info.baseName(); // base = env

            info.setFile("/etc/hosts");
        path = info.absolutePath(); // path = /etc
            base = info.baseName();
        // base = hosts

        **See also** **isFile** (), **isRelative** (), **QDir::setCurrent** (),
        and **QDir::isRelativePath** ().
        """
        ...

    @typing.overload
    def setFile(self, file: QFileDevice) -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#setFile-1

        **void QFileInfo::setFile(const QFileDevice & file )**

        This is an overloaded function.

        Sets the file that the **QFileInfo**  provides information about to
        **file**.

        If **file** includes a relative path, the **QFileInfo**  will also have
        a relative path.

        **See also** **isRelative** ().
        """
        ...

    @typing.overload
    def setFile(self, dir: QDir, file: str) -> None:
        """
        https://doc.qt.io/qt-6/qfileinfo.html#setFile-2

        **void QFileInfo::setFile(const QDir & dir , const QString & file )**

        This is an overloaded function.

        Sets the file that the **QFileInfo**  provides information about to
        **file** in directory **dir**.

        If **file** includes a relative path, the **QFileInfo**  will also have
        a relative path.

        **See also** **isRelative** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QPointingDeviceUniqueId(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpointingdeviceuniqueid.html

    **Detailed Description**

    QPointingDeviceUniqueIds can be compared for equality, and can be used as
    keys in a **QHash** . You get access to the numerical ID via **numericId**
    (), if the device supports such IDs. For future extensions, though, you
    should not use that function, but compare objects of this type using the
    equality operator.

    This class is a thin wrapper around an integer ID. You pass it into and out
    of functions by value.

    **See also** **QEventPoint** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpointingdeviceuniqueid.html#QPointingDeviceUniqu
        eId

        **QPointingDeviceUniqueId::QPointingDeviceUniqueId()**

        Constructs an invalid unique pointer ID.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QPointingDeviceUniqueId") -> None:
        """
        https://doc.qt.io/qt-6/qpointingdeviceuniqueid.html#QPointingDeviceUniqu
        eId

        **QPointingDeviceUniqueId::QPointingDeviceUniqueId()**

        Constructs an invalid unique pointer ID.
        """
        ...

    def __hash__(self) -> int:
        ...

    def numericId(self) -> int:
        """
        https://doc.qt.io/qt-6/qpointingdeviceuniqueid.html#numericId-prop

        **[read-only] numericId : const qint64**

        This property holds the numeric unique ID of the token represented by a
        touchpoint

        If the device provides a numeric ID, **isValid** () returns true, and
        this property provides the numeric ID; otherwise it is -1.

        You should not use the value of this property in portable code, but
        instead rely on equality to identify pointers.

        **Access functions:**

        qint64 **numericId** () const

        **See also** **isValid** ().

        **Member Function Documentation**
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpointingdeviceuniqueid.html#isValid

        **bool QPointingDeviceUniqueId::isValid() const**

        Returns whether this unique pointer ID is valid, that is, it represents
        an actual pointer.
        """
        ...

    @staticmethod
    def fromNumericId(id: int) -> "QPointingDeviceUniqueId":
        """
        https://doc.qt.io/qt-6/qpointingdeviceuniqueid.html#fromNumericId

        **[static] QPointingDeviceUniqueId
        QPointingDeviceUniqueId::fromNumericId(qint64 id )**

        Constructs a unique pointer ID from numeric ID **id**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QFileDialog(QDialog):
    """
    https://doc.qt.io/qt-6/qfiledialog.html

    **Detailed Description**

    The QFileDialog class enables a user to traverse the file system in order to
    select one or many files or a directory.

    The easiest way to create a QFileDialog is to use the static functions.

    fileName = **QFileDialog** ::getOpenFileName(this,
            tr("Open Image"),
    "/home/jana", tr("Image Files (*.png *.jpg *.bmp)"));

    In the above example, a modal QFileDialog is created using a static
    function. The dialog initially displays the contents of the "/home/jana"
    directory, and displays files matching the patterns given in the string
    "Image Files (*.png *.jpg *.bmp)". The parent of the file dialog is set to
    **this** , and the window title is set to "Open Image".

    If you want to use multiple filters, separate each one with **two**
    semicolons. For example:

    "Images (*.png *.xpm *.jpg);;Text files (*.txt);;XML files (*.xml)"

    You can create your own QFileDialog without using the static functions. By
    calling **setFileMode** (), you can specify what the user must select in the
    dialog:

    **QFileDialog**  dialog(this);
        dialog.setFileMode(**QFileDialog**
    ::AnyFile);

    In the above example, the mode of the file dialog is set to **AnyFile** ,
    meaning that the user can select any file, or even specify a file that
    doesn't exist. This mode is useful for creating a "Save As" file dialog. Use
    **ExistingFile**  if the user must select an existing file, or **Directory**
    if only a directory may be selected. See the **QFileDialog::FileMode**  enum
    for the complete list of modes.

    The **fileMode**  property contains the mode of operation for the dialog;
    this indicates what types of objects the user is expected to select. Use
    **setNameFilter** () to set the dialog's file filter. For example:

    dialog.setNameFilter(tr("Images (*.png *.xpm *.jpg)"));

    In the above example, the filter is set to `"Images (*.png *.xpm *.jpg)"`,
    this means that only files with the extension `png`, `xpm`, or `jpg` will be
    shown in the QFileDialog. You can apply several filters by using
    **setNameFilters** (). Use **selectNameFilter** () to select one of the
    filters you've given as the file dialog's default filter.

    The file dialog has two view modes: **List**  and **Detail** . **List**
    presents the contents of the current directory as a list of file and
    directory names. **Detail**  also displays a list of file and directory
    names, but provides additional information alongside each name, such as the
    file size and modification date. Set the mode with **setViewMode** ():

    dialog.setViewMode(**QFileDialog** ::Detail);

    The last important function you will need to use when creating your own file
    dialog is **selectedFiles** ().

    **QStringList**  fileNames;
        if (dialog.exec())
            fileNames =
    dialog.selectedFiles();

    In the above example, a modal file dialog is created and shown. If the user
    clicked OK, the file they selected is put in `fileName`.

    The dialog's working directory can be set with **setDirectory** (). Each
    file in the current directory can be selected using the **selectFile** ()
    function.

    The **Standard Dialogs**  example shows how to use QFileDialog as well as
    other built-in Qt dialogs.

    By default, a platform-native file dialog will be used if the platform has
    one. In that case, the widgets which would otherwise be used to construct
    the dialog will not be instantiated, so related accessors such as **layout**
    () and **itemDelegate** () will return null. You can set the
    **DontUseNativeDialog**  option to ensure that the widget-based
    implementation will be used instead of the native dialog.

    **See also** **QDir** , **QFileInfo** , **QFile** , **QColorDialog** ,
    **QFontDialog** , **Standard Dialogs Example** , and **Qt Widgets -
    Application Example** .
    """

    class Option(enum.Flag):
        ShowDirsOnly: QFileDialog = ...
        DontResolveSymlinks: QFileDialog = ...
        DontConfirmOverwrite: QFileDialog = ...
        DontUseNativeDialog: QFileDialog = ...
        ReadOnly: QFileDialog = ...
        HideNameFilterDetails: QFileDialog = ...
        DontUseCustomDirectoryIcons: QFileDialog = ...

    class DialogLabel(enum.Enum):
        LookIn: QFileDialog = ...
        FileName: QFileDialog = ...
        FileType: QFileDialog = ...
        Accept: QFileDialog = ...
        Reject: QFileDialog = ...

    class AcceptMode(enum.Enum):
        AcceptOpen: QFileDialog = ...
        AcceptSave: QFileDialog = ...

    class FileMode(enum.Enum):
        AnyFile: QFileDialog = ...
        ExistingFile: QFileDialog = ...
        Directory: QFileDialog = ...
        ExistingFiles: QFileDialog = ...

    class ViewMode(enum.Enum):
        Detail: QFileDialog = ...
        List: QFileDialog = ...

    @typing.overload
    def __init__(self, parent: QWidget, f: QtCore.Qt.WindowType) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#QFileDialog

        **QFileDialog::QFileDialog(QWidget * parent , Qt::WindowFlags flags )**

        Constructs a file dialog with the given **parent** and widget **flags**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        parent: typing.Optional[QWidget] = ...,
        caption: str = ...,
        directory: str = ...,
        filter: str = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#QFileDialog-1

        **QFileDialog::QFileDialog(QWidget * parent = nullptr, const QString &
        caption = QString(), const QString & directory = QString(), const
        QString & filter = QString())**

        Constructs a file dialog with the given **parent** and **caption** that
        initially displays the contents of the specified **directory**. The
        contents of the directory are filtered before being shown in the dialog,
        using a semicolon-separated list of filters specified by **filter**.
        """
        ...

    @staticmethod
    def saveFileContent(
        fileContent: QtCore.QByteArray, fileNameHint: str = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#saveFileContent

        **[static, since 5.14] void QFileDialog::saveFileContent(const
        QByteArray & fileContent , const QString & fileNameHint = QString())**

        This is a convenience static function that saves **fileContent** to a
        file, using a file name and location chosen by the user.
        **fileNameHint** can be provided to suggest a file name to the user.

        This function is used to save files to the local file system on Qt for
        WebAssembly, where the web sandbox places restrictions on how such
        access may happen. Its implementation will make the browser display a
        native file dialog, where the user makes the file selection.

        It can also be used on other platforms, where it will fall back to using
        **QFileDialog** .

        The function is asynchronous and returns immediately.

        **QByteArray**  imageData; // obtained from e.g. QImage::save()
        **QFileDialog** ::saveFile("myimage.png", imageData);

        This function was introduced in Qt 5.14.
        """
        ...

    def selectedMimeTypeFilter(self) -> str:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#selectedMimeTypeFilter

        **[since 5.9] QString QFileDialog::selectedMimeTypeFilter() const**

        Returns The mimetype of the file that the user selected in the file
        dialog.

        This function was introduced in Qt 5.9.
        """
        ...

    def supportedSchemes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#supportedSchemes-prop

        **[since 5.6] supportedSchemes : QStringList**

        This property holds the URL schemes that the file dialog should allow
        navigating to.

        Setting this property allows to restrict the type of URLs the user will
        be able to select. It is a way for the application to declare the
        protocols it will support to fetch the file content. An empty list means
        that no restriction is applied (the default). Supported for local files
        ("file" scheme) is implicit and always enabled; it is not necessary to
        include it in the restriction.

        This property was introduced in Qt 5.6.

        **Access functions:**

        QStringList **supportedSchemes** () const
        void **setSupportedSchemes**
        (const QStringList & **schemes** )
        """
        ...

    def setSupportedSchemes(self, schemes: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#supportedSchemes-prop

        **[since 5.6] supportedSchemes : QStringList**

        This property holds the URL schemes that the file dialog should allow
        navigating to.

        Setting this property allows to restrict the type of URLs the user will
        be able to select. It is a way for the application to declare the
        protocols it will support to fetch the file content. An empty list means
        that no restriction is applied (the default). Supported for local files
        ("file" scheme) is implicit and always enabled; it is not necessary to
        include it in the restriction.

        This property was introduced in Qt 5.6.

        **Access functions:**

        QStringList **supportedSchemes** () const
        void **setSupportedSchemes**
        (const QStringList & **schemes** )
        """
        ...

    @staticmethod
    def getSaveFileUrl(
        parent: typing.Optional[QWidget] = ...,
        caption: str = ...,
        directory: QtCore.QUrl = ...,
        filter: str = ...,
        initialFilter: str = ...,
        options: "QFileDialog.Option" = ...,
        supportedSchemes: typing.Iterable[str] = ...,
    ) -> typing.Tuple[QtCore.QUrl, str]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#getSaveFileUrl

        **[static, since 5.2] QUrl QFileDialog::getSaveFileUrl(QWidget * parent
        = nullptr, const QString & caption = QString(), const QUrl & dir =
        QUrl(), const QString & filter = QString(), QString * selectedFilter =
        nullptr, QFileDialog::Options options = Options(), const QStringList &
        supportedSchemes = QStringList())**

        This is a convenience static function that returns a file selected by
        the user. The file does not have to exist. If the user presses Cancel,
        it returns an empty url.

        The function is used similarly to **QFileDialog::getSaveFileName** ().
        In particular **parent** , **caption** , **dir** , **filter** ,
        **selectedFilter** and **options** are used in the exact same way.

        The main difference with **QFileDialog::getSaveFileName** () comes from
        the ability offered to the user to select a remote file. That's why the
        return type and the type of **dir** is **QUrl** .

        The **supportedSchemes** argument allows to restrict the type of URLs
        the user will be able to select. It is a way for the application to
        declare the protocols it will support to save the file content. An empty
        list means that no restriction is applied (the default). Supported for
        local files ("file" scheme) is implicit and always enabled; it is not
        necessary to include it in the restriction.

        When possible, this static function will use the native file dialog and
        not a **QFileDialog** . On platforms which don't support selecting
        remote files, Qt will allow to select only local files.

        This function was introduced in Qt 5.2.

        **See also** **getSaveFileName** (), **getOpenFileUrl** (),
        **getOpenFileUrls** (), and **getExistingDirectoryUrl** ().
        """
        ...

    @staticmethod
    def getOpenFileUrls(
        parent: typing.Optional[QWidget] = ...,
        caption: str = ...,
        directory: QtCore.QUrl = ...,
        filter: str = ...,
        initialFilter: str = ...,
        options: "QFileDialog.Option" = ...,
        supportedSchemes: typing.Iterable[str] = ...,
    ) -> typing.Tuple[typing.List[QtCore.QUrl], str]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#getOpenFileUrls

        **[static, since 5.2] QList<QUrl> QFileDialog::getOpenFileUrls(QWidget *
        parent = nullptr, const QString & caption = QString(), const QUrl & dir
        = QUrl(), const QString & filter = QString(), QString * selectedFilter =
        nullptr, QFileDialog::Options options = Options(), const QStringList &
        supportedSchemes = QStringList())**

        This is a convenience static function that will return one or more
        existing files selected by the user. If the user presses Cancel, it
        returns an empty list.

        The function is used similarly to **QFileDialog::getOpenFileNames** ().
        In particular **parent** , **caption** , **dir** , **filter** ,
        **selectedFilter** and **options** are used in the exact same way.

        The main difference with **QFileDialog::getOpenFileNames** () comes from
        the ability offered to the user to select remote files. That's why the
        return type and the type of **dir** are respectively **QList** <**QUrl**
        > and **QUrl** .

        The **supportedSchemes** argument allows to restrict the type of URLs
        the user will be able to select. It is a way for the application to
        declare the protocols it will support to fetch the file content. An
        empty list means that no restriction is applied (the default). Supported
        for local files ("file" scheme) is implicit and always enabled; it is
        not necessary to include it in the restriction.

        When possible, this static function will use the native file dialog and
        not a **QFileDialog** . On platforms which don't support selecting
        remote files, Qt will allow to select only local files.

        This function was introduced in Qt 5.2.

        **See also** **getOpenFileNames** (), **getOpenFileUrl** (),
        **getSaveFileUrl** (), and **getExistingDirectoryUrl** ().
        """
        ...

    @staticmethod
    def getOpenFileUrl(
        parent: typing.Optional[QWidget] = ...,
        caption: str = ...,
        directory: QtCore.QUrl = ...,
        filter: str = ...,
        initialFilter: str = ...,
        options: "QFileDialog.Option" = ...,
        supportedSchemes: typing.Iterable[str] = ...,
    ) -> typing.Tuple[QtCore.QUrl, str]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#getOpenFileUrl

        **[static, since 5.2] QUrl QFileDialog::getOpenFileUrl(QWidget * parent
        = nullptr, const QString & caption = QString(), const QUrl & dir =
        QUrl(), const QString & filter = QString(), QString * selectedFilter =
        nullptr, QFileDialog::Options options = Options(), const QStringList &
        supportedSchemes = QStringList())**

        This is a convenience static function that returns an existing file
        selected by the user. If the user presses Cancel, it returns an empty
        url.

        The function is used similarly to **QFileDialog::getOpenFileName** ().
        In particular **parent** , **caption** , **dir** , **filter** ,
        **selectedFilter** and **options** are used in the exact same way.

        The main difference with **QFileDialog::getOpenFileName** () comes from
        the ability offered to the user to select a remote file. That's why the
        return type and the type of **dir** is **QUrl** .

        The **supportedSchemes** argument allows to restrict the type of URLs
        the user will be able to select. It is a way for the application to
        declare the protocols it will support to fetch the file content. An
        empty list means that no restriction is applied (the default). Supported
        for local files ("file" scheme) is implicit and always enabled; it is
        not necessary to include it in the restriction.

        When possible, this static function will use the native file dialog and
        not a **QFileDialog** . On platforms which don't support selecting
        remote files, Qt will allow to select only local files.

        This function was introduced in Qt 5.2.

        **See also** **getOpenFileName** (), **getOpenFileUrls** (),
        **getSaveFileUrl** (), and **getExistingDirectoryUrl** ().
        """
        ...

    def selectMimeTypeFilter(self, filter: str) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#selectMimeTypeFilter

        **[since 5.2] void QFileDialog::selectMimeTypeFilter(const QString &
        filter )**

        Sets the current MIME type **filter**.

        This function was introduced in Qt 5.2.
        """
        ...

    def mimeTypeFilters(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#mimeTypeFilters

        **[since 5.2] QStringList QFileDialog::mimeTypeFilters() const**

        Returns the MIME type filters that are in operation on this file dialog.

        This function was introduced in Qt 5.2.

        **See also** **setMimeTypeFilters** ().
        """
        ...

    def setMimeTypeFilters(self, filters: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setMimeTypeFilters

        **[since 5.2] void QFileDialog::setMimeTypeFilters(const QStringList &
        filters )**

        Sets the **filters** used in the file dialog, from a list of MIME types.

        Convenience method for **setNameFilters** (). Uses **QMimeType**  to
        create a name filter from the glob patterns and description defined in
        each MIME type.

        Use application/octet-stream for the "All files (*)" filter, since that
        is the base MIME type for all files.

        Calling setMimeTypeFilters overrides any previously set name filters,
        and changes the return value of **nameFilters** ().

        **QStringList**  mimeTypeFilters({"image/jpeg", // will show "JPEG image
        (*.jpeg *.jpg *.jpe)
                                         "image/png",  //
        will show "PNG image (*.png)"
        "application/octet-stream" // will show "All files (*)"
        });

            **QFileDialog**  dialog(this);
        dialog.setMimeTypeFilters(mimeTypeFilters);
            dialog.exec();

        This function was introduced in Qt 5.2.

        **See also** **mimeTypeFilters** ().
        """
        ...

    def selectedUrls(self) -> typing.List[QtCore.QUrl]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#selectedUrls

        **[since 5.2] QList<QUrl> QFileDialog::selectedUrls() const**

        Returns a list of urls containing the selected files in the dialog. If
        no files are selected, or the mode is not **ExistingFiles**  or
        **ExistingFile** , selectedUrls() contains the current path in the
        viewport.

        This function was introduced in Qt 5.2.

        **See also** **selectedNameFilter** () and **selectUrl** ().
        """
        ...

    def selectUrl(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#selectUrl

        **[since 5.2] void QFileDialog::selectUrl(const QUrl & url )**

        Selects the given **url** in the file dialog.

        **Note:** The non-native **QFileDialog**  supports only local files.

        This function was introduced in Qt 5.2.

        **See also** **selectedUrls** ().
        """
        ...

    def directoryUrl(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#directoryUrl

        **[since 5.2] QUrl QFileDialog::directoryUrl() const**

        Returns the url of the directory currently being displayed in the
        dialog.

        This function was introduced in Qt 5.2.

        **See also** **setDirectoryUrl** ().
        """
        ...

    def setDirectoryUrl(self, directory: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setDirectoryUrl

        **[since 5.2] void QFileDialog::setDirectoryUrl(const QUrl & directory
        )**

        Sets the file dialog's current **directory** url.

        **Note:** The non-native **QFileDialog**  supports only local files.

        **Note:** On Windows, it is possible to pass URLs representing one of
        the **virtual folders** , such as "Computer" or "Network". This is done
        by passing a **QUrl**  using the scheme `clsid` followed by the CLSID
        value with the curly braces removed. For example the URL
        `clsid:374DE290-123F-4565-9164-39C4925E467B` denotes the download
        location. For a complete list of possible values, see the MSDN
        documentation on **KNOWNFOLDERID** . This feature was added in Qt 5.5.

        This function was introduced in Qt 5.2.

        **See also** **directoryUrl** () and **QUuid** .
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setVisible

        **[override virtual] void QFileDialog::setVisible(bool visible )**

        Reimplements: **QDialog::setVisible** (bool visible).
        """
        ...

    @typing.overload
    def open(self) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#open

        **void QFileDialog::open(QObject * receiver , const char * member )**

        This function connects one of its signals to the slot specified by
        **receiver** and **member**. The specific signal depends is
        **filesSelected** () if **fileMode**  is **ExistingFiles**  and
        **fileSelected** () if **fileMode**  is anything else.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    @typing.overload
    def open(self, slot: PYQT_SLOT) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#open

        **void QFileDialog::open(QObject * receiver , const char * member )**

        This function connects one of its signals to the slot specified by
        **receiver** and **member**. The specific signal depends is
        **filesSelected** () if **fileMode**  is **ExistingFiles**  and
        **fileSelected** () if **fileMode**  is anything else.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    def options(self) -> "QFileDialog.Option":
        """
        https://doc.qt.io/qt-6/qfiledialog.html#options-prop

        **options : Options**

        This property holds the various options that affect the look and feel of
        the dialog

        By default, all options are disabled.

        Options (particularly the DontUseNativeDialogs option) should be set
        before changing dialog properties or showing the dialog.

        Setting options while the dialog is visible is not guaranteed to have an
        immediate effect on the dialog (depending on the option and on the
        platform).

        Setting options after changing other properties may cause these values
        to have no effect.

        **Access functions:**

        QFileDialog::Options **options** () const
        void **setOptions**
        (QFileDialog::Options **options** )

        **See also** **setOption** () and **testOption** ().
        """
        ...

    def setOptions(self, options: "QFileDialog.Option") -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#options-prop

        **options : Options**

        This property holds the various options that affect the look and feel of
        the dialog

        By default, all options are disabled.

        Options (particularly the DontUseNativeDialogs option) should be set
        before changing dialog properties or showing the dialog.

        Setting options while the dialog is visible is not guaranteed to have an
        immediate effect on the dialog (depending on the option and on the
        platform).

        Setting options after changing other properties may cause these values
        to have no effect.

        **Access functions:**

        QFileDialog::Options **options** () const
        void **setOptions**
        (QFileDialog::Options **options** )

        **See also** **setOption** () and **testOption** ().
        """
        ...

    def testOption(self, option: "QFileDialog.Option") -> bool:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#testOption

        **bool QFileDialog::testOption(QFileDialog::Option option ) const**

        Returns `true` if the given **option** is enabled; otherwise, returns
        false.

        **See also** **options**  and **setOption** ().
        """
        ...

    def setOption(self, option: "QFileDialog.Option", on: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setOption

        **void QFileDialog::setOption(QFileDialog::Option option , bool on =
        true)**

        Sets the given **option** to be enabled if **on** is true; otherwise,
        clears the given **option**.

        Options (particularly the DontUseNativeDialogs option) should be set
        before changing dialog properties or showing the dialog.

        Setting options while the dialog is visible is not guaranteed to have an
        immediate effect on the dialog (depending on the option and on the
        platform).

        Setting options after changing other properties may cause these values
        to have no effect.

        **See also** **options**  and **testOption** ().
        """
        ...

    def setFilter(self, filters: QtCore.QDir.Filter) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setFilter

        **void QFileDialog::setFilter(QDir::Filters filters )**

        Sets the filter used by the model to **filters**. The filter is used to
        specify the kind of files that should be shown.

        **See also** **filter** ().
        """
        ...

    def filter(self) -> QtCore.QDir.Filter:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#filter

        **QDir::Filters QFileDialog::filter() const**

        Returns the filter that is used when displaying files.

        **See also** **setFilter** ().
        """
        ...

    def selectedNameFilter(self) -> str:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#selectedNameFilter

        **QString QFileDialog::selectedNameFilter() const**

        Returns the filter that the user selected in the file dialog.

        **See also** **selectedFiles** ().
        """
        ...

    def selectNameFilter(self, filter: str) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#selectNameFilter

        **void QFileDialog::selectNameFilter(const QString & filter )**

        Sets the current file type **filter**. Multiple filters can be passed in
        **filter** by separating them with semicolons or spaces.

        **See also** **setNameFilter** (), **setNameFilters** (), and
        **selectedNameFilter** ().
        """
        ...

    def nameFilters(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#nameFilters

        **QStringList QFileDialog::nameFilters() const**

        Returns the file type filters that are in operation on this file dialog.

        **See also** **setNameFilters** ().
        """
        ...

    def setNameFilters(self, filters: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setNameFilters

        **void QFileDialog::setNameFilters(const QStringList & filters )**

        Sets the **filters** used in the file dialog.

        Note that the filter ***.*** is not portable, because the historical
        assumption that the file extension determines the file type is not
        consistent on every operating system. It is possible to have a file with
        no dot in its name (for example, `Makefile`). In a native Windows file
        dialog, ***.*** will match such files, while in other types of file
        dialogs it may not. So it is better to use ***** if you mean to select
        any file.

        const **QStringList**  filters({"Image files (*.png *.xpm *.jpg)",
        "Text files (*.txt)",
                                       "Any files (*)"
        });
            **QFileDialog**  dialog(this);
        dialog.setNameFilters(filters);
            dialog.exec();

        **setMimeTypeFilters** () has the advantage of providing all possible
        name filters for each file type. For example, JPEG images have three
        possible extensions; if your application can open such files, selecting
        the `image/jpeg` mime type as a filter will allow you to open all of
        them.

        **See also** **nameFilters** ().
        """
        ...

    def setNameFilter(self, filter: str) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setNameFilter

        **void QFileDialog::setNameFilter(const QString & filter )**

        Sets the filter used in the file dialog to the given **filter**.

        If **filter** contains a pair of parentheses containing one or more
        filename-wildcard patterns, separated by spaces, then only the text
        contained in the parentheses is used as the filter. This means that
        these calls are all equivalent:

        dialog.setNameFilter("All C++ files (*.cpp *.cc *.C *.cxx *.c++)");
        dialog.setNameFilter("*.cpp *.cc *.C *.cxx *.c++");

        **Note:** With Android's native file dialog, the mime type matching the
        given name filter is used because only mime types are supported.

        **See also** **setMimeTypeFilters** () and **setNameFilters** ().
        """
        ...

    def proxyModel(self) -> QtCore.QAbstractProxyModel:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#proxyModel

        **QAbstractProxyModel *QFileDialog::proxyModel() const**

        Returns the proxy model used by the file dialog. By default no proxy is
        set.

        **See also** **setProxyModel** ().
        """
        ...

    def setProxyModel(self, model: QtCore.QAbstractProxyModel) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setProxyModel

        **void QFileDialog::setProxyModel(QAbstractProxyModel * proxyModel )**

        Sets the model for the views to the given **proxyModel**. This is useful
        if you want to modify the underlying model; for example, to add columns,
        filter data or add drives.

        Any existing proxy model will be removed, but not deleted. The file
        dialog will take ownership of the **proxyModel**.

        **See also** **proxyModel** ().
        """
        ...

    def restoreState(self, state: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#restoreState

        **bool QFileDialog::restoreState(const QByteArray & state )**

        Restores the dialogs's layout, history and current directory to the
        **state** specified.

        Typically this is used in conjunction with **QSettings**  to restore the
        size from a past session.

        Returns `false` if there are errors
        """
        ...

    def saveState(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#saveState

        **QByteArray QFileDialog::saveState() const**

        Saves the state of the dialog's layout, history and current directory.

        Typically this is used in conjunction with **QSettings**  to remember
        the size for a future session. A version number is stored as part of the
        data.
        """
        ...

    def sidebarUrls(self) -> typing.List[QtCore.QUrl]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#sidebarUrls

        **QList<QUrl> QFileDialog::sidebarUrls() const**

        Returns a list of urls that are currently in the sidebar

        **See also** **setSidebarUrls** ().
        """
        ...

    def setSidebarUrls(self, urls: typing.Iterable[QtCore.QUrl]) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setSidebarUrls

        **void QFileDialog::setSidebarUrls(const QList<QUrl> & urls )**

        Sets the **urls** that are located in the sidebar.

        For instance:

        **QList** <**QUrl** > urls;
                urls << **QUrl**
        ::fromLocalFile("/Users/foo/Code/qt5")
                     << **QUrl**
        ::fromLocalFile(**QStandardPaths**
        ::standardLocations(**QStandardPaths** ::MusicLocation).first());
        **QFileDialog**  dialog;
                dialog.setSidebarUrls(urls);
        dialog.setFileMode(**QFileDialog** ::AnyFile);
                if
        (dialog.exec()) {
                    // ...
                }

        The file dialog will then look like this:

        ![](images/filedialogurls.png)

        **See also** **sidebarUrls** ().
        """
        ...

    def changeEvent(self, e: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#changeEvent

        **[override virtual protected] void QFileDialog::changeEvent(QEvent * e
        )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def accept(self) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#accept

        **[override virtual protected] void QFileDialog::accept()**

        Reimplements: **QDialog::accept** ().
        """
        ...

    def done(self, result: int) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#done

        **[override virtual protected] void QFileDialog::done(int result )**

        Reimplements: **QDialog::done** (int r).
        """
        ...

    @staticmethod
    def getSaveFileName(
        parent: typing.Optional[QWidget] = ...,
        caption: str = ...,
        directory: str = ...,
        filter: str = ...,
        initialFilter: str = ...,
        options: "QFileDialog.Option" = ...,
    ) -> typing.Tuple[str, str]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#getSaveFileName

        **[static] QString QFileDialog::getSaveFileName(QWidget * parent =
        nullptr, const QString & caption = QString(), const QString & dir =
        QString(), const QString & filter = QString(), QString * selectedFilter
        = nullptr, QFileDialog::Options options = Options())**

        This is a convenience static function that will return a file name
        selected by the user. The file does not have to exist.

        It creates a modal file dialog with the given **parent** widget. If
        **parent** is not `nullptr`, the dialog will be shown centered over the
        parent widget.

        **QString**  fileName = **QFileDialog** ::getSaveFileName(this, tr("Save
        File"),
                                       "/home/jana/untitled.png",
        tr("Images (*.png *.xpm *.jpg)"));

        The file dialog's working directory will be set to **dir**. If **dir**
        includes a file name, the file will be selected. Only files that match
        the **filter** are shown. The filter selected is set to
        **selectedFilter**. The parameters **dir** , **selectedFilter** , and
        **filter** may be empty strings. Multiple filters are separated with
        ';;'. For instance:

        "Images (*.png *.xpm *.jpg);;Text files (*.txt);;XML files (*.xml)"

        The **options** argument holds various options about how to run the
        dialog, see the **QFileDialog::Option**  enum for more information on
        the flags you can pass.

        The default filter can be chosen by setting **selectedFilter** to the
        desired value.

        The dialog's caption is set to **caption**. If **caption** is not
        specified, a default caption will be used.

        On Windows, and macOS, this static function will use the native file
        dialog and not a **QFileDialog** .

        On Windows the dialog will spin a blocking modal event loop that will
        not dispatch any QTimers, and if **parent** is not `nullptr` then it
        will position the dialog just below the parent's title bar. On macOS,
        with its native file dialog, the filter argument is ignored.

        On Unix/X11, the normal behavior of the file dialog is to resolve and
        follow symlinks. For example, if `/usr/tmp` is a symlink to `/var/tmp`,
        the file dialog will change to `/var/tmp` after entering `/usr/tmp`. If
        **options** includes **DontResolveSymlinks**  the file dialog will treat
        symlinks as regular directories.

        **Warning:** Do not delete **parent** during the execution of the
        dialog. If you want to do this, you should create the dialog yourself
        using one of the **QFileDialog**  constructors.

        **See also** **getOpenFileName** (), **getOpenFileNames** (), and
        **getExistingDirectory** ().
        """
        ...

    @staticmethod
    def getOpenFileNames(
        parent: typing.Optional[QWidget] = ...,
        caption: str = ...,
        directory: str = ...,
        filter: str = ...,
        initialFilter: str = ...,
        options: "QFileDialog.Option" = ...,
    ) -> typing.Tuple[typing.List[str], str]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#getOpenFileNames

        **[static] QStringList QFileDialog::getOpenFileNames(QWidget * parent =
        nullptr, const QString & caption = QString(), const QString & dir =
        QString(), const QString & filter = QString(), QString * selectedFilter
        = nullptr, QFileDialog::Options options = Options())**

        This is a convenience static function that will return one or more
        existing files selected by the user.

        **QStringList**  files = **QFileDialog** ::getOpenFileNames(
        this,
                                    "Select one or more files to open",
        "/home",
                                    "Images (*.png *.xpm *.jpg)");

        This function creates a modal file dialog with the given **parent**
        widget. If **parent** is not `nullptr`, the dialog will be shown
        centered over the parent widget.

        The file dialog's working directory will be set to **dir**. If **dir**
        includes a file name, the file will be selected. The filter is set to
        **filter** so that only those files which match the filter are shown.
        The filter selected is set to **selectedFilter**. The parameters **dir**
        , **selectedFilter** and **filter** may be empty strings. If you need
        multiple filters, separate them with ';;', for instance:

        "Images (*.png *.xpm *.jpg);;Text files (*.txt);;XML files (*.xml)"

        The dialog's caption is set to **caption**. If **caption** is not
        specified then a default caption will be used.

        On Windows, and macOS, this static function will use the native file
        dialog and not a **QFileDialog** .

        On Windows the dialog will spin a blocking modal event loop that will
        not dispatch any QTimers, and if **parent** is not `nullptr` then it
        will position the dialog just below the parent's title bar.

        On Unix/X11, the normal behavior of the file dialog is to resolve and
        follow symlinks. For example, if `/usr/tmp` is a symlink to `/var/tmp`,
        the file dialog will change to `/var/tmp` after entering `/usr/tmp`. The
        **options** argument holds various options about how to run the dialog,
        see the **QFileDialog::Option**  enum for more information on the flags
        you can pass.

        **Warning:** Do not delete **parent** during the execution of the
        dialog. If you want to do this, you should create the dialog yourself
        using one of the **QFileDialog**  constructors.

        **See also** **getOpenFileName** (), **getSaveFileName** (), and
        **getExistingDirectory** ().
        """
        ...

    @staticmethod
    def getOpenFileName(
        parent: typing.Optional[QWidget] = ...,
        caption: str = ...,
        directory: str = ...,
        filter: str = ...,
        initialFilter: str = ...,
        options: "QFileDialog.Option" = ...,
    ) -> typing.Tuple[str, str]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#getOpenFileName

        **[static] QString QFileDialog::getOpenFileName(QWidget * parent =
        nullptr, const QString & caption = QString(), const QString & dir =
        QString(), const QString & filter = QString(), QString * selectedFilter
        = nullptr, QFileDialog::Options options = Options())**

        This is a convenience static function that returns an existing file
        selected by the user. If the user presses Cancel, it returns a null
        string.

        **QString**  fileName = **QFileDialog** ::getOpenFileName(this, tr("Open
        File"),
                                                            "/home",
        tr("Images (*.png *.xpm *.jpg)"));

        The function creates a modal file dialog with the given **parent**
        widget. If **parent** is not `nullptr`, the dialog will be shown
        centered over the parent widget.

        The file dialog's working directory will be set to **dir**. If **dir**
        includes a file name, the file will be selected. Only files that match
        the given **filter** are shown. The filter selected is set to
        **selectedFilter**. The parameters **dir** , **selectedFilter** , and
        **filter** may be empty strings. If you want multiple filters, separate
        them with ';;', for example:

        "Images (*.png *.xpm *.jpg);;Text files (*.txt);;XML files (*.xml)"

        The **options** argument holds various options about how to run the
        dialog, see the **QFileDialog::Option**  enum for more information on
        the flags you can pass.

        The dialog's caption is set to **caption**. If **caption** is not
        specified then a default caption will be used.

        On Windows, and macOS, this static function will use the native file
        dialog and not a **QFileDialog** .

        On Windows the dialog will spin a blocking modal event loop that will
        not dispatch any QTimers, and if **parent** is not `nullptr` then it
        will position the dialog just below the parent's title bar.

        On Unix/X11, the normal behavior of the file dialog is to resolve and
        follow symlinks. For example, if `/usr/tmp` is a symlink to `/var/tmp`,
        the file dialog will change to `/var/tmp` after entering `/usr/tmp`. If
        **options** includes **DontResolveSymlinks** , the file dialog will
        treat symlinks as regular directories.

        **Warning:** Do not delete **parent** during the execution of the
        dialog. If you want to do this, you should create the dialog yourself
        using one of the **QFileDialog**  constructors.

        **See also** **getOpenFileNames** (), **getSaveFileName** (), and
        **getExistingDirectory** ().
        """
        ...

    @staticmethod
    def getExistingDirectoryUrl(
        parent: typing.Optional[QWidget] = ...,
        caption: str = ...,
        directory: QtCore.QUrl = ...,
        options: "QFileDialog.Option" = ...,
        supportedSchemes: typing.Iterable[str] = ...,
    ) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#getExistingDirectoryUrl

        **[static, since 5.2] QUrl QFileDialog::getExistingDirectoryUrl(QWidget
        * parent = nullptr, const QString & caption = QString(), const QUrl &
        dir = QUrl(), QFileDialog::Options options = ShowDirsOnly, const
        QStringList & supportedSchemes = QStringList())**

        This is a convenience static function that will return an existing
        directory selected by the user. If the user presses Cancel, it returns
        an empty url.

        The function is used similarly to **QFileDialog::getExistingDirectory**
        (). In particular **parent** , **caption** , **dir** and **options** are
        used in the exact same way.

        The main difference with **QFileDialog::getExistingDirectory** () comes
        from the ability offered to the user to select a remote directory.
        That's why the return type and the type of **dir** is **QUrl** .

        The **supportedSchemes** argument allows to restrict the type of URLs
        the user will be able to select. It is a way for the application to
        declare the protocols it will support to fetch the file content. An
        empty list means that no restriction is applied (the default). Supported
        for local files ("file" scheme) is implicit and always enabled; it is
        not necessary to include it in the restriction.

        When possible, this static function will use the native file dialog and
        not a **QFileDialog** . On platforms which don't support selecting
        remote files, Qt will allow to select only local files.

        This function was introduced in Qt 5.2.

        **See also** **getExistingDirectory** (), **getOpenFileUrl** (),
        **getOpenFileUrls** (), and **getSaveFileUrl** ().
        """
        ...

    @staticmethod
    def getExistingDirectory(
        parent: typing.Optional[QWidget] = ...,
        caption: str = ...,
        directory: str = ...,
        options: "QFileDialog.Option" = ...,
    ) -> str:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#getExistingDirectory

        **[static] QString QFileDialog::getExistingDirectory(QWidget * parent =
        nullptr, const QString & caption = QString(), const QString & dir =
        QString(), QFileDialog::Options options = ShowDirsOnly)**

        This is a convenience static function that will return an existing
        directory selected by the user.

        **QString**  dir = **QFileDialog** ::getExistingDirectory(this, tr("Open
        Directory"),
        "/home",
        **QFileDialog** ::ShowDirsOnly
        | **QFileDialog** ::DontResolveSymlinks);

        This function creates a modal file dialog with the given **parent**
        widget. If **parent** is not `nullptr`, the dialog will be shown
        centered over the parent widget.

        The dialog's working directory is set to **dir** , and the caption is
        set to **caption**. Either of these may be an empty string in which case
        the current directory and a default caption will be used respectively.

        The **options** argument holds various options about how to run the
        dialog, see the **QFileDialog::Option**  enum for more information on
        the flags you can pass. To ensure a native file dialog, **ShowDirsOnly**
        must be set.

        On Windows and macOS, this static function will use the native file
        dialog and not a **QFileDialog** . However, the native Windows file
        dialog does not support displaying files in the directory chooser. You
        need to pass **DontUseNativeDialog**  to display files using a
        **QFileDialog** .

        On Unix/X11, the normal behavior of the file dialog is to resolve and
        follow symlinks. For example, if `/usr/tmp` is a symlink to `/var/tmp`,
        the file dialog will change to `/var/tmp` after entering `/usr/tmp`. If
        **options** includes **DontResolveSymlinks** , the file dialog will
        treat symlinks as regular directories.

        On Windows, the dialog will spin a blocking modal event loop that will
        not dispatch any QTimers, and if **parent** is not `nullptr` then it
        will position the dialog just below the parent's title bar.

        **Warning:** Do not delete **parent** during the execution of the
        dialog. If you want to do this, you should create the dialog yourself
        using one of the **QFileDialog**  constructors.

        **See also** **getOpenFileName** (), **getOpenFileNames** (), and
        **getSaveFileName** ().
        """
        ...

    def labelText(self, label: "QFileDialog.DialogLabel") -> str:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#labelText

        **QString QFileDialog::labelText(QFileDialog::DialogLabel label )
        const**

        Returns the text shown in the filedialog in the specified **label**.

        **See also** **setLabelText** ().
        """
        ...

    def setLabelText(self, label: "QFileDialog.DialogLabel", text: str) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setLabelText

        **void QFileDialog::setLabelText(QFileDialog::DialogLabel label , const
        QString & text )**

        Sets the **text** shown in the filedialog in the specified **label**.

        **See also** **labelText** ().
        """
        ...

    def iconProvider(self) -> QtGui.QAbstractFileIconProvider:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#iconProvider

        **QAbstractFileIconProvider *QFileDialog::iconProvider() const**

        Returns the icon provider used by the filedialog.

        **See also** **setIconProvider** ().
        """
        ...

    def setIconProvider(self, provider: QtGui.QAbstractFileIconProvider) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setIconProvider

        **void QFileDialog::setIconProvider(QAbstractFileIconProvider * provider
        )**

        Sets the icon provider used by the filedialog to the specified
        **provider**.

        **See also** **iconProvider** ().
        """
        ...

    def itemDelegate(self) -> QAbstractItemDelegate:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#itemDelegate

        **QAbstractItemDelegate *QFileDialog::itemDelegate() const**

        Returns the item delegate used to render the items in the views in the
        filedialog.

        **See also** **setItemDelegate** ().
        """
        ...

    def setItemDelegate(self, delegate: QAbstractItemDelegate) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setItemDelegate

        **void QFileDialog::setItemDelegate(QAbstractItemDelegate * delegate )**

        Sets the item delegate used to render items in the views in the file
        dialog to the given **delegate**.

        Any existing delegate will be removed, but not deleted. **QFileDialog**
        does not take ownership of **delegate**.

        **Warning:** You should not share the same instance of a delegate
        between views. Doing so can cause incorrect or unintuitive editing
        behavior since each view connected to a given delegate may receive the
        **closeEditor** () signal, and attempt to access, modify or close an
        editor that has already been closed.

        Note that the model used is **QFileSystemModel** . It has custom item
        data roles, which is described by the **Roles**  enum. You can use a
        **QFileIconProvider**  if you only want custom icons.

        **See also** **itemDelegate** (), **setIconProvider** (), and
        **QFileSystemModel** .
        """
        ...

    def history(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#history

        **QStringList QFileDialog::history() const**

        Returns the browsing history of the filedialog as a list of paths.

        **See also** **setHistory** ().
        """
        ...

    def setHistory(self, paths: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setHistory

        **void QFileDialog::setHistory(const QStringList & paths )**

        Sets the browsing history of the filedialog to contain the given
        **paths**.

        **See also** **history** ().
        """
        ...

    def defaultSuffix(self) -> str:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#defaultSuffix-prop

        **defaultSuffix : QString**

        suffix added to the filename if no other suffix was specified

        This property specifies a string that will be added to the filename if
        it has no suffix already. The suffix is typically used to indicate the
        file type (e.g. "txt" indicates a text file).

        If the first character is a dot ('.'), it is removed.

        **Access functions:**

        QString **defaultSuffix** () const
        void **setDefaultSuffix** (const
        QString & **suffix** )
        """
        ...

    def setDefaultSuffix(self, suffix: str) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#defaultSuffix-prop

        **defaultSuffix : QString**

        suffix added to the filename if no other suffix was specified

        This property specifies a string that will be added to the filename if
        it has no suffix already. The suffix is typically used to indicate the
        file type (e.g. "txt" indicates a text file).

        If the first character is a dot ('.'), it is removed.

        **Access functions:**

        QString **defaultSuffix** () const
        void **setDefaultSuffix** (const
        QString & **suffix** )
        """
        ...

    def acceptMode(self) -> "QFileDialog.AcceptMode":
        """
        https://doc.qt.io/qt-6/qfiledialog.html#acceptMode-prop

        **acceptMode : AcceptMode**

        This property holds the accept mode of the dialog

        The action mode defines whether the dialog is for opening or saving
        files.

        By default, this property is set to **AcceptOpen** .

        **Access functions:**

        QFileDialog::AcceptMode **acceptMode** () const
        void **setAcceptMode**
        (QFileDialog::AcceptMode **mode** )

        **See also** **AcceptMode** .
        """
        ...

    def setAcceptMode(self, mode: "QFileDialog.AcceptMode") -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#acceptMode-prop

        **acceptMode : AcceptMode**

        This property holds the accept mode of the dialog

        The action mode defines whether the dialog is for opening or saving
        files.

        By default, this property is set to **AcceptOpen** .

        **Access functions:**

        QFileDialog::AcceptMode **acceptMode** () const
        void **setAcceptMode**
        (QFileDialog::AcceptMode **mode** )

        **See also** **AcceptMode** .
        """
        ...

    def fileMode(self) -> "QFileDialog.FileMode":
        """
        https://doc.qt.io/qt-6/qfiledialog.html#fileMode-prop

        **fileMode : FileMode**

        This property holds the file mode of the dialog

        The file mode defines the number and type of items that the user is
        expected to select in the dialog.

        By default, this property is set to **AnyFile** .

        This function will set the labels for the **FileName**  and **Accept**
        **DialogLabel** s. It is possible to set custom text after the call to
        setFileMode().

        **Access functions:**

        QFileDialog::FileMode **fileMode** () const
        void **setFileMode**
        (QFileDialog::FileMode **mode** )

        **See also** **FileMode** .
        """
        ...

    def setFileMode(self, mode: "QFileDialog.FileMode") -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#fileMode-prop

        **fileMode : FileMode**

        This property holds the file mode of the dialog

        The file mode defines the number and type of items that the user is
        expected to select in the dialog.

        By default, this property is set to **AnyFile** .

        This function will set the labels for the **FileName**  and **Accept**
        **DialogLabel** s. It is possible to set custom text after the call to
        setFileMode().

        **Access functions:**

        QFileDialog::FileMode **fileMode** () const
        void **setFileMode**
        (QFileDialog::FileMode **mode** )

        **See also** **FileMode** .
        """
        ...

    def viewMode(self) -> "QFileDialog.ViewMode":
        """
        https://doc.qt.io/qt-6/qfiledialog.html#viewMode-prop

        **viewMode : ViewMode**

        This property holds the way files and directories are displayed in the
        dialog

        By default, the `Detail` mode is used to display information about files
        and directories.

        **Access functions:**

        QFileDialog::ViewMode **viewMode** () const
        void **setViewMode**
        (QFileDialog::ViewMode **mode** )

        **See also** **ViewMode** .

        **Member Function Documentation**
        """
        ...

    def setViewMode(self, mode: "QFileDialog.ViewMode") -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#viewMode-prop

        **viewMode : ViewMode**

        This property holds the way files and directories are displayed in the
        dialog

        By default, the `Detail` mode is used to display information about files
        and directories.

        **Access functions:**

        QFileDialog::ViewMode **viewMode** () const
        void **setViewMode**
        (QFileDialog::ViewMode **mode** )

        **See also** **ViewMode** .

        **Member Function Documentation**
        """
        ...

    def selectedFiles(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#selectedFiles

        **QStringList QFileDialog::selectedFiles() const**

        Returns a list of strings containing the absolute paths of the selected
        files in the dialog. If no files are selected, or the mode is not
        **ExistingFiles**  or **ExistingFile** , selectedFiles() contains the
        current path in the viewport.

        **See also** **selectedNameFilter** () and **selectFile** ().
        """
        ...

    def selectFile(self, filename: str) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#selectFile

        **void QFileDialog::selectFile(const QString & filename )**

        Selects the given **filename** in the file dialog.

        **See also** **selectedFiles** ().
        """
        ...

    def directory(self) -> QtCore.QDir:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#directory

        **QDir QFileDialog::directory() const**

        Returns the directory currently being displayed in the dialog.

        **See also** **setDirectory** ().
        """
        ...

    @typing.overload
    def setDirectory(self, directory: str) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setDirectory

        **void QFileDialog::setDirectory(const QString & directory )**

        Sets the file dialog's current **directory**.

        **Note:** On iOS, if you set **directory** to **QStandardPaths::standard
        Locations(QStandardPaths::PicturesLocation).last** (), a native image
        picker dialog will be used for accessing the user's photo album. The
        filename returned can be loaded using **QFile**  and related APIs. For
        this to be enabled, the Info.plist assigned to QMAKE_INFO_PLIST in the
        project file must contain the key `NSPhotoLibraryUsageDescription`. See
        Info.plist documentation from Apple for more information regarding this
        key. This feature was added in Qt 5.5.

        **See also** **directory** ().
        """
        ...

    @typing.overload
    def setDirectory(self, adirectory: QtCore.QDir) -> None:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#setDirectory-1

        **void QFileDialog::setDirectory(const QDir & directory )**

        This is an overloaded function.
        """
        ...

    @property
    def currentChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#currentChanged

        **[signal] void QFileDialog::currentChanged(const QString & path )**

        When the current file changes for local operations, this signal is
        emitted with the new file name as the **path** parameter.

        **See also** **filesSelected** ().
        """
        ...

    @property
    def currentUrlChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#currentUrlChanged

        **[signal, since 5.2] void QFileDialog::currentUrlChanged(const QUrl &
        url )**

        When the current file changes, this signal is emitted with the new file
        URL as the **url** parameter.

        This function was introduced in Qt 5.2.

        **See also** **urlsSelected** ().
        """
        ...

    @property
    def directoryEntered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#directoryEntered

        **[signal] void QFileDialog::directoryEntered(const QString & directory
        )**

        This signal is emitted for local operations when the user enters a
        **directory**.
        """
        ...

    @property
    def directoryUrlEntered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#directoryUrlEntered

        **[signal, since 5.2] void QFileDialog::directoryUrlEntered(const QUrl &
        directory )**

        This signal is emitted when the user enters a **directory**.

        This function was introduced in Qt 5.2.
        """
        ...

    @property
    def fileSelected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#fileSelected

        **[signal] void QFileDialog::fileSelected(const QString & file )**

        When the selection changes for local operations and the dialog is
        accepted, this signal is emitted with the (possibly empty) selected
        **file**.

        **See also** **currentChanged** () and **QDialog::Accepted** .
        """
        ...

    @property
    def filesSelected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#filesSelected

        **[signal] void QFileDialog::filesSelected(const QStringList & selected
        )**

        When the selection changes for local operations and the dialog is
        accepted, this signal is emitted with the (possibly empty) list of
        **selected** files.

        **See also** **currentChanged** () and **QDialog::Accepted** .
        """
        ...

    @property
    def filterSelected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#filterSelected

        **[signal] void QFileDialog::filterSelected(const QString & filter )**

        This signal is emitted when the user selects a **filter**.
        """
        ...

    @property
    def urlSelected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#urlSelected

        **[signal, since 5.2] void QFileDialog::urlSelected(const QUrl & url )**

        When the selection changes and the dialog is accepted, this signal is
        emitted with the (possibly empty) selected **url**.

        This function was introduced in Qt 5.2.

        **See also** **currentUrlChanged** () and **QDialog::Accepted** .
        """
        ...

    @property
    def urlsSelected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfiledialog.html#urlsSelected

        **[signal, since 5.2] void QFileDialog::urlsSelected(const QList<QUrl> &
        urls )**

        When the selection changes and the dialog is accepted, this signal is
        emitted with the (possibly empty) list of selected **urls**.

        This function was introduced in Qt 5.2.

        **See also** **currentUrlChanged** () and **QDialog::Accepted** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QDragMoveEvent(QDropEvent):
    """
    https://doc.qt.io/qt-6/qdragmoveevent.html

    **Detailed Description**

    A widget will receive drag move events repeatedly while the drag is within
    its boundaries, if it accepts **drop events**  and **enter events** . The
    widget should examine the event to see what kind of **data**  it provides,
    and call the **accept** () function to accept the drop if appropriate.

    The rectangle supplied by the **answerRect** () function can be used to
    restrict drops to certain parts of the widget. For example, we can check
    whether the rectangle intersects with the geometry of a certain child widget
    and only call **acceptProposedAction** () if that is the case.

    Note that this class inherits most of its functionality from **QDropEvent**
    .

    **See also** **QDragEnterEvent** , **QDragLeaveEvent** , and **QDropEvent**
    .
    """

    def __init__(
        self,
        pos: QtCore.QPoint,
        actions: QtCore.Qt.DropAction,
        data: QtCore.QMimeData,
        buttons: QtCore.Qt.MouseButton,
        modifiers: QtCore.Qt.KeyboardModifier,
        type: QtCore.QEvent.Type = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdragmoveevent.html#QDragMoveEvent-2

        **QDragMoveEvent::QDragMoveEvent(const QPoint & pos , Qt::DropActions
        actions , const QMimeData * data , Qt::MouseButtons buttons ,
        Qt::KeyboardModifiers modifiers , QEvent::Type type = DragMove)**

        Creates a QDragMoveEvent of the required **type** indicating that the
        mouse is at position **pos** given within a widget.

        The mouse and keyboard states are specified by **buttons** and
        **modifiers** , and the **actions** describe the types of drag and drop
        operation that are possible. The drag data is passed as MIME-encoded
        information in **data**.

        **Warning:** Do not attempt to create a QDragMoveEvent yourself. These
        objects rely on Qt's internal state.
        """
        ...

    def clone(self) -> "QDragMoveEvent":
        ...

    @typing.overload
    def ignore(self) -> None:
        """
        https://doc.qt.io/qt-6/qdragmoveevent.html#ignore

        **void QDragMoveEvent::ignore(const QRect & rectangle )**

        The opposite of the accept(const **QRect** &) function. Moves within the
        **rectangle** are not acceptable, and will be ignored.
        """
        ...

    @typing.overload
    def ignore(self, r: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qdragmoveevent.html#ignore-1

        **void QDragMoveEvent::ignore()**

        This is an overloaded function.

        Calls **QDropEvent::ignore** ().
        """
        ...

    @typing.overload
    def accept(self) -> None:
        """
        https://doc.qt.io/qt-6/qdragmoveevent.html#accept

        **void QDragMoveEvent::accept(const QRect & rectangle )**

        The same as accept(), but also notifies that future moves will also be
        acceptable if they remain within the **rectangle** given on the widget.
        This can improve performance, but may also be ignored by the underlying
        system.

        If the rectangle is empty, drag move events will be sent continuously.
        This is useful if the source is scrolling in a timer event.
        """
        ...

    @typing.overload
    def accept(self, r: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qdragmoveevent.html#accept-1

        **void QDragMoveEvent::accept()**

        This is an overloaded function.

        Calls **QDropEvent::accept** ().
        """
        ...

    def answerRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qdragmoveevent.html#answerRect

        **QRect QDragMoveEvent::answerRect() const**

        Returns the rectangle in the widget where the drop will occur if
        accepted. You can use this information to restrict drops to certain
        places on the widget.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QOpenGLContextGroup(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qopenglcontextgroup.html

    **Detailed Description**

    QOpenGLContextGroup is automatically created and managed by
    **QOpenGLContext**  instances. Its purpose is to identify all the contexts
    that are sharing resources.

    **See also** **QOpenGLContext::shareGroup** ().
    """

    @staticmethod
    def currentContextGroup() -> "QOpenGLContextGroup":
        """
        https://doc.qt.io/qt-6/qopenglcontextgroup.html#currentContextGroup

        **[static] QOpenGLContextGroup
        *QOpenGLContextGroup::currentContextGroup()**

        Returns the **QOpenGLContextGroup**  corresponding to the current
        context.

        **See also** **QOpenGLContext::currentContext** ().
        """
        ...

    def shares(self) -> typing.List["QOpenGLContext"]:
        """
        https://doc.qt.io/qt-6/qopenglcontextgroup.html#shares

        **QList<QOpenGLContext *> QOpenGLContextGroup::shares() const**

        Returns all the **QOpenGLContext**  objects in this share group.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QHttp2Configuration(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhttp2configuration.html

    **Detailed Description**

    QHttp2Configuration controls HTTP/2 parameters and settings that
    **QNetworkAccessManager**  will use to send requests and process responses
    when the HTTP/2 protocol is enabled.

    The HTTP/2 parameters that QHttp2Configuration currently supports include:

    * The session window size for connection-level flow control. Will be sent to
    a remote peer when needed as 'WINDOW_UPDATE' frames on the stream with an
    identifier 0.
      * The stream receiving window size for stream-level flow
    control. Sent as 'SETTINGS_INITIAL_WINDOW_SIZE' parameter in the initial
    SETTINGS frame and, when needed, 'WINDOW_UPDATE' frames will be sent on
    streams that **QNetworkAccessManager**  opens.
      * The maximum frame size.
    This parameter limits the maximum payload a frame coming from the remote
    peer can have. Sent by **QNetworkAccessManager**  as
    'SETTINGS_MAX_FRAME_SIZE' parameter in the initial 'SETTINGS' frame.
      * The
    server push. Allows to enable or disable server push. Sent as
    'SETTINGS_ENABLE_PUSH' parameter in the initial 'SETTINGS' frame.

    The QHttp2Configuration class also controls if the header compression
    algorithm (HPACK) is additionally using Huffman coding for string
    compression.

    **Note:** The configuration must be set before the first request was sent to
    a given host (and thus an HTTP/2 session established).

    **Note:** Details about flow control, server push and 'SETTINGS' can be
    found in **RFC 7540** . Different modes and parameters of the HPACK
    compression algorithm are described in **RFC 7541** .

    **See also** **QNetworkRequest::setHttp2Configuration** (),
    **QNetworkRequest::http2Configuration** (), and **QNetworkAccessManager** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#QHttp2Configuration

        **QHttp2Configuration::QHttp2Configuration()**

        Default constructs a QHttp2Configuration object.

        Such a configuration has the following values:

        * Server push is disabled
          * Huffman string compression is enabled
          *
        Window size for connection-level flow control is 65535 octets
          * Window
        size for stream-level flow control is 65535 octets
          * Frame size is
        16384 octets
        """
        ...

    @typing.overload
    def __init__(self, other: "QHttp2Configuration") -> None:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#QHttp2Configuration-1

        **QHttp2Configuration::QHttp2Configuration(const QHttp2Configuration &
        other )**

        Copy-constructs this QHttp2Configuration.
        """
        ...

    def swap(self, other: "QHttp2Configuration") -> None:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#swap

        **void QHttp2Configuration::swap(QHttp2Configuration & other )**

        Swaps this configuration with the **other** configuration.
        """
        ...

    def maxFrameSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#maxFrameSize

        **unsigned int QHttp2Configuration::maxFrameSize() const**

        Returns the maximum payload size that HTTP/2 frames can have. The
        default (initial) value is 16384 octets.

        **See also** **setMaxFrameSize** ().
        """
        ...

    def setMaxFrameSize(self, size: int) -> bool:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#setMaxFrameSize

        **bool QHttp2Configuration::setMaxFrameSize(unsigned int size )**

        Sets the maximum frame size that **QNetworkAccessManager**  will
        advertise to the server when sending its initial SETTINGS frame.

        **Note:** While this **size** is required to be within a range between
        16384 and 16777215 inclusive, the actual payload size in frames that
        carry payload maybe be less than 16384.

        Returns `true` on success, `false` otherwise.

        **See also** **maxFrameSize** ().
        """
        ...

    def streamReceiveWindowSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#streamReceiveWindowSize

        **unsigned int QHttp2Configuration::streamReceiveWindowSize() const**

        Returns the window size for stream-level flow control. The default value
        **QNetworkAccessManager**  will be using is 65535 octets (see **RFC
        7540** ).

        **See also** **setStreamReceiveWindowSize** ().
        """
        ...

    def setStreamReceiveWindowSize(self, size: int) -> bool:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#setStreamReceiveWindowSi
        ze

        **bool QHttp2Configuration::setStreamReceiveWindowSize(unsigned int size
        )**

        Sets the window size for stream-level flow control. **size** cannot be 0
        and must not exceed 2147483647 octets.

        Returns `true` on success, `false` otherwise.

        **See also** **streamReceiveWindowSize** .
        """
        ...

    def sessionReceiveWindowSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#sessionReceiveWindowSize

        **unsigned int QHttp2Configuration::sessionReceiveWindowSize() const**

        Returns the window size for connection-level flow control. The default
        value **QNetworkAccessManager**  will be using is 2147483647 octets.

        **See also** **setSessionReceiveWindowSize** ().
        """
        ...

    def setSessionReceiveWindowSize(self, size: int) -> bool:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#setSessionReceiveWindowS
        ize

        **bool QHttp2Configuration::setSessionReceiveWindowSize(unsigned int
        size )**

        Sets the window size for connection-level flow control. **size** cannot
        be 0 and must not exceed 2147483647 octets.

        Returns `true` on success, `false` otherwise.

        **See also** **sessionReceiveWindowSize** .
        """
        ...

    def huffmanCompressionEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#huffmanCompressionEnable
        d

        **bool QHttp2Configuration::huffmanCompressionEnabled() const**

        Returns `true` if the Huffman coding in HPACK is enabled.

        **See also** **setHuffmanCompressionEnabled** .
        """
        ...

    def setHuffmanCompressionEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#setHuffmanCompressionEna
        bled

        **void QHttp2Configuration::setHuffmanCompressionEnabled(bool enable )**

        If **enable** is `true`, HPACK compression will additionally compress
        string using the Huffman coding. Enabled by default.

        **Note:** This parameter only affects 'HEADERS' frames that
        **QNetworkAccessManager**  is sending.

        **See also** **huffmanCompressionEnabled** .
        """
        ...

    def serverPushEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#serverPushEnabled

        **bool QHttp2Configuration::serverPushEnabled() const**

        Returns true if server push was enabled.

        **Note:** By default, **QNetworkAccessManager**  disables server push
        via the 'SETTINGS' frame.

        **See also** **setServerPushEnabled** .
        """
        ...

    def setServerPushEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qhttp2configuration.html#setServerPushEnabled

        **void QHttp2Configuration::setServerPushEnabled(bool enable )**

        If **enable** is `true`, a remote server can potentially use server push
        to send responses in advance.

        **See also** **serverPushEnabled** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QNetworkReply(QtCore.QIODevice):
    """
    https://doc.qt.io/qt-6/qnetworkreply.html

    **Detailed Description**

    The QNetworkReply class contains the data and meta data related to a request
    posted with **QNetworkAccessManager** . Like **QNetworkRequest** , it
    contains a URL and headers (both in parsed and raw form), some information
    about the reply's state and the contents of the reply itself.

    QNetworkReply is a sequential-access **QIODevice** , which means that once
    data is read from the object, it no longer kept by the device. It is
    therefore the application's responsibility to keep this data if it needs to.
    Whenever more data is received from the network and processed, the
    **readyRead** () signal is emitted.

    The **downloadProgress** () signal is also emitted when data is received,
    but the number of bytes contained in it may not represent the actual bytes
    received, if any transformation is done to the contents (for example,
    decompressing and removing the protocol overhead).

    Even though QNetworkReply is a **QIODevice**  connected to the contents of
    the reply, it also emits the **uploadProgress** () signal, which indicates
    the progress of the upload for operations that have such content.

    **Note:** Do not delete the object in the slot connected to the
    **errorOccurred** () or **finished** () signal. Use **deleteLater** ().

    **See also** **QNetworkRequest**  and **QNetworkAccessManager** .
    """

    class NetworkError(enum.Enum):
        NoError: QNetworkReply = ...
        ConnectionRefusedError: QNetworkReply = ...
        RemoteHostClosedError: QNetworkReply = ...
        HostNotFoundError: QNetworkReply = ...
        TimeoutError: QNetworkReply = ...
        OperationCanceledError: QNetworkReply = ...
        SslHandshakeFailedError: QNetworkReply = ...
        UnknownNetworkError: QNetworkReply = ...
        ProxyConnectionRefusedError: QNetworkReply = ...
        ProxyConnectionClosedError: QNetworkReply = ...
        ProxyNotFoundError: QNetworkReply = ...
        ProxyTimeoutError: QNetworkReply = ...
        ProxyAuthenticationRequiredError: QNetworkReply = ...
        UnknownProxyError: QNetworkReply = ...
        ContentAccessDenied: QNetworkReply = ...
        ContentOperationNotPermittedError: QNetworkReply = ...
        ContentNotFoundError: QNetworkReply = ...
        AuthenticationRequiredError: QNetworkReply = ...
        UnknownContentError: QNetworkReply = ...
        ProtocolUnknownError: QNetworkReply = ...
        ProtocolInvalidOperationError: QNetworkReply = ...
        ProtocolFailure: QNetworkReply = ...
        ContentReSendError: QNetworkReply = ...
        TemporaryNetworkFailureError: QNetworkReply = ...
        NetworkSessionFailedError: QNetworkReply = ...
        BackgroundRequestNotAllowedError: QNetworkReply = ...
        ContentConflictError: QNetworkReply = ...
        ContentGoneError: QNetworkReply = ...
        InternalServerError: QNetworkReply = ...
        OperationNotImplementedError: QNetworkReply = ...
        ServiceUnavailableError: QNetworkReply = ...
        UnknownServerError: QNetworkReply = ...
        TooManyRedirectsError: QNetworkReply = ...
        InsecureRedirectError: QNetworkReply = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#QNetworkReply

        **[protected] QNetworkReply::QNetworkReply(QObject * parent = nullptr)**

        Creates a QNetworkReply object with parent **parent**.

        You cannot directly instantiate QNetworkReply objects. Use
        **QNetworkAccessManager**  functions to do that.
        """
        ...

    def ignoreSslErrorsImplementation(self, a0: typing.Iterable["QSslError"]) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#ignoreSslErrorsImplementation

        **[virtual protected, since 5.0] void
        QNetworkReply::ignoreSslErrorsImplementation(const QList<QSslError> &
        errors )**

        This virtual method is provided to enable overriding the behavior of
        **ignoreSslErrors** (). **ignoreSslErrors** () is a public wrapper for
        this method. **errors** contains the errors the user wishes ignored.

        This function was introduced in Qt 5.0.

        **See also** **ignoreSslErrors** ().
        """
        ...

    def setSslConfigurationImplementation(self, a0: "QSslConfiguration") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#setSslConfigurationImplementat
        ion

        **[virtual protected, since 5.0] void
        QNetworkReply::setSslConfigurationImplementation(const QSslConfiguration
        & configuration )**

        This virtual method is provided to enable overriding the behavior of
        **setSslConfiguration** (). **setSslConfiguration** () is a public
        wrapper for this method. If you override this method use
        **configuration** to set the SSL configuration.

        This function was introduced in Qt 5.0.

        **See also** **sslConfigurationImplementation** () and
        **setSslConfiguration** ().
        """
        ...

    def sslConfigurationImplementation(self, a0: "QSslConfiguration") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#sslConfigurationImplementation

        **[virtual protected, since 5.0] void
        QNetworkReply::sslConfigurationImplementation(QSslConfiguration &
        configuration ) const**

        This virtual method is provided to enable overriding the behavior of
        **sslConfiguration** (). **sslConfiguration** () is a public wrapper for
        this method. The configuration will be returned in **configuration**.

        This function was introduced in Qt 5.0.

        **See also** **setSslConfigurationImplementation** () and
        **sslConfiguration** ().
        """
        ...

    def rawHeaderPairs(
        self,
    ) -> typing.List[typing.Tuple[QtCore.QByteArray, QtCore.QByteArray]]:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#rawHeaderPairs

        **const QList<QNetworkReply::RawHeaderPair>
        &QNetworkReply::rawHeaderPairs() const**

        Returns a list of raw header pairs.
        """
        ...

    def isRunning(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#isRunning

        **bool QNetworkReply::isRunning() const**

        Returns `true` when the request is still processing and the reply has
        not finished or was aborted yet.

        **See also** **isFinished** ().
        """
        ...

    def isFinished(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#isFinished

        **bool QNetworkReply::isFinished() const**

        Returns `true` when the reply has finished or was aborted.

        **See also** **isRunning** ().
        """
        ...

    def setFinished(self, finished: bool) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#setFinished

        **[protected] void QNetworkReply::setFinished(bool finished )**

        Sets the reply as **finished**.

        After having this set the replies data must not change.

        **See also** **finished** () and **isFinished** ().
        """
        ...

    def setAttribute(
        self, code: "QNetworkRequest.Attribute", value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#setAttribute

        **[protected] void
        QNetworkReply::setAttribute(QNetworkRequest::Attribute code , const
        QVariant & value )**

        Sets the attribute **code** to have value **value**. If **code** was
        previously set, it will be overridden. If **value** is an invalid
        **QVariant** , the attribute will be unset.

        **See also** **attribute** () and **QNetworkRequest::setAttribute** ().
        """
        ...

    def setRawHeader(
        self, headerName: QtCore.QByteArray, value: QtCore.QByteArray
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#setRawHeader

        **[protected] void QNetworkReply::setRawHeader(const QByteArray &
        headerName , const QByteArray & value )**

        Sets the raw header **headerName** to be of value **value**. If
        **headerName** was previously set, it is overridden. Multiple HTTP
        headers of the same name are functionally equivalent to one single
        header with the values concatenated, separated by commas.

        If **headerName** matches a known header, the value **value** will be
        parsed and the corresponding parsed form will also be set.

        **See also** **rawHeader** (), **header** (), **setHeader** (), and
        **QNetworkRequest::setRawHeader** ().
        """
        ...

    def setHeader(
        self, header: "QNetworkRequest.KnownHeaders", value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#setHeader

        **[protected] void
        QNetworkReply::setHeader(QNetworkRequest::KnownHeaders header , const
        QVariant & value )**

        Sets the known header **header** to be of value **value**. The
        corresponding raw form of the header will be set as well.

        **See also** **header** (), **setRawHeader** (), and
        **QNetworkRequest::setHeader** ().
        """
        ...

    def setUrl(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#setUrl

        **[protected] void QNetworkReply::setUrl(const QUrl & url )**

        Sets the URL being processed to be **url**. Normally, the URL matches
        that of the request that was posted, but for a variety of reasons it can
        be different (for example, a file path being made absolute or
        canonical).

        **See also** **url** (), **request** (), and **QNetworkRequest::url**
        ().
        """
        ...

    def setError(
        self, errorCode: "QNetworkReply.NetworkError", errorString: str
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#setError

        **[protected] void QNetworkReply::setError(QNetworkReply::NetworkError
        errorCode , const QString & errorString )**

        Sets the error condition to be **errorCode**. The human-readable message
        is set with **errorString**.

        Calling setError() does not emit the **errorOccurred**
        (**QNetworkReply::NetworkError** ) signal.

        **See also** **error** () and **errorString** ().
        """
        ...

    def setRequest(self, request: "QNetworkRequest") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#setRequest

        **[protected] void QNetworkReply::setRequest(const QNetworkRequest &
        request )**

        Sets the associated request for this object to be **request**. This
        value will be returned by **request** ().

        **Note:** The request should be set when this object is created and not
        changed again.

        **See also** **request** () and **setOperation** ().
        """
        ...

    def setOperation(self, operation: QNetworkAccessManager.Operation) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#setOperation

        **[protected] void
        QNetworkReply::setOperation(QNetworkAccessManager::Operation operation
        )**

        Sets the associated operation for this object to be **operation**. This
        value will be returned by **operation** ().

        **Note:** The operation should be set when this object is created and
        not changed again.

        **See also** **operation** () and **setRequest** ().
        """
        ...

    def writeData(self, a0: PyQt6.sip.Buffer) -> int:
        ...

    @typing.overload
    def ignoreSslErrors(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#ignoreSslErrors

        **[virtual slot] void QNetworkReply::ignoreSslErrors()**

        If this function is called, SSL errors related to network connection
        will be ignored, including certificate validation errors.

        **Warning:** Be sure to always let the user inspect the errors reported
        by the **sslErrors** () signal, and only call this method upon
        confirmation from the user that proceeding is ok. If there are
        unexpected errors, the reply should be aborted. Calling this method
        without inspecting the actual errors will most likely pose a security
        risk for your application. Use it with great care!

        This function can be called from the slot connected to the **sslErrors**
        () signal, which indicates which errors were found.

        **Note:** If HTTP Strict Transport Security is enabled for
        **QNetworkAccessManager** , this function has no effect.

        **See also** **sslConfiguration** (), **sslErrors** (), and
        **QSslSocket::ignoreSslErrors** ().
        """
        ...

    @typing.overload
    def ignoreSslErrors(self, errors: typing.Iterable["QSslError"]) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#ignoreSslErrors-1

        **void QNetworkReply::ignoreSslErrors(const QList<QSslError> & errors
        )**

        This is an overloaded function.

        If this function is called, the SSL errors given in **errors** will be
        ignored.

        **Note:** Because most SSL errors are associated with a certificate, for
        most of them you must set the expected certificate this SSL error is
        related to. If, for instance, you want to issue a request to a server
        that uses a self-signed certificate, consider the following snippet:

        **QList** <**QSslCertificate** > cert = **QSslCertificate**
        ::fromPath(QLatin1String("server-certificate.pem"));
            **QSslError**
        error(**QSslError** ::SelfSignedCertificate, cert.at(0));
            **QList**
        <**QSslError** > expectedSslErrors;
            expectedSslErrors.append(error);
        **QNetworkReply**  *reply = manager.get(**QNetworkRequest** (**QUrl**
        ("https://server.tld/index.html")));
        reply->ignoreSslErrors(expectedSslErrors);
            // here connect signals
        etc.

        Multiple calls to this function will replace the list of errors that
        were passed in previous calls. You can clear the list of errors you want
        to ignore by calling this function with an empty list.

        **Note:** If HTTP Strict Transport Security is enabled for
        **QNetworkAccessManager** , this function has no effect.

        **See also** **sslConfiguration** (), **sslErrors** (),
        **QSslSocket::ignoreSslErrors** (), and
        **QNetworkAccessManager::setStrictTransportSecurityEnabled** ().
        """
        ...

    def setSslConfiguration(self, configuration: "QSslConfiguration") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#setSslConfiguration

        **void QNetworkReply::setSslConfiguration(const QSslConfiguration &
        config )**

        Sets the SSL configuration for the network connection associated with
        this request, if possible, to be that of **config**.

        **See also** **sslConfiguration** ().
        """
        ...

    def sslConfiguration(self) -> "QSslConfiguration":
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#sslConfiguration

        **QSslConfiguration QNetworkReply::sslConfiguration() const**

        Returns the SSL configuration and state associated with this reply, if
        SSL was used. It will contain the remote server's certificate, its
        certificate chain leading to the Certificate Authority as well as the
        encryption ciphers in use.

        The peer's certificate and its certificate chain will be known by the
        time **sslErrors** () is emitted, if it's emitted.

        **See also** **setSslConfiguration** ().
        """
        ...

    def attribute(self, code: "QNetworkRequest.Attribute") -> typing.Any:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#attribute

        **QVariant QNetworkReply::attribute(QNetworkRequest::Attribute code )
        const**

        Returns the attribute associated with the code **code**. If the
        attribute has not been set, it returns an invalid **QVariant**  (type
        **QMetaType::UnknownType** ).

        You can expect the default values listed in
        **QNetworkRequest::Attribute**  to be applied to the values returned by
        this function.

        **See also** **setAttribute** () and **QNetworkRequest::Attribute** .
        """
        ...

    def rawHeader(self, headerName: QtCore.QByteArray) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#rawHeader

        **QByteArray QNetworkReply::rawHeader(const QByteArray & headerName )
        const**

        Returns the raw contents of the header **headerName** as sent by the
        remote server. If there is no such header, returns an empty byte array,
        which may be indistinguishable from an empty header. Use
        **hasRawHeader** () to verify if the server sent such header field.

        **See also** **setRawHeader** (), **hasRawHeader** (), and **header**
        ().
        """
        ...

    def rawHeaderList(self) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#rawHeaderList

        **QList<QByteArray> QNetworkReply::rawHeaderList() const**

        Returns a list of headers fields that were sent by the remote server, in
        the order that they were sent. Duplicate headers are merged together and
        take place of the latter duplicate.
        """
        ...

    def hasRawHeader(self, headerName: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#hasRawHeader

        **bool QNetworkReply::hasRawHeader(const QByteArray & headerName )
        const**

        Returns `true` if the raw header of name **headerName** was sent by the
        remote server

        **See also** **rawHeader** ().
        """
        ...

    def header(self, header: "QNetworkRequest.KnownHeaders") -> typing.Any:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#header

        **QVariant QNetworkReply::header(QNetworkRequest::KnownHeaders header )
        const**

        Returns the value of the known header **header** , if that header was
        sent by the remote server. If the header was not sent, returns an
        invalid **QVariant** .

        **See also** **rawHeader** (), **setHeader** (), and
        **QNetworkRequest::header** ().
        """
        ...

    def url(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#url

        **QUrl QNetworkReply::url() const**

        Returns the URL of the content downloaded or uploaded. Note that the URL
        may be different from that of the original request. If redirections were
        enabled in the request, then this function returns the current url that
        the network API is accessing, i.e the url of the resource the request
        got redirected to.

        **See also** **request** (), **setUrl** (), **QNetworkRequest::url** (),
        and **redirected** ().
        """
        ...

    def error(self) -> "QNetworkReply.NetworkError":
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#error

        **QNetworkReply::NetworkError QNetworkReply::error() const**

        Returns the error that was found during the processing of this request.
        If no error was found, returns **NoError** .

        **See also** **setError** ().
        """
        ...

    def request(self) -> "QNetworkRequest":
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#request

        **QNetworkRequest QNetworkReply::request() const**

        Returns the request that was posted for this reply. In special, note
        that the URL for the request may be different than that of the reply.

        **See also** **QNetworkRequest::url** (), **url** (), and **setRequest**
        ().
        """
        ...

    def operation(self) -> QNetworkAccessManager.Operation:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#operation

        **QNetworkAccessManager::Operation QNetworkReply::operation() const**

        Returns the operation that was posted for this reply.

        **See also** **setOperation** ().
        """
        ...

    def manager(self) -> QNetworkAccessManager:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#manager

        **QNetworkAccessManager *QNetworkReply::manager() const**

        Returns the **QNetworkAccessManager**  that was used to create this
        **QNetworkReply**  object. Initially, it is also the parent object.
        """
        ...

    def setReadBufferSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#setReadBufferSize

        **[virtual] void QNetworkReply::setReadBufferSize(qint64 size )**

        Sets the size of the read buffer to be **size** bytes. The read buffer
        is the buffer that holds data that is being downloaded off the network,
        before it is read with **QIODevice::read** (). Setting the buffer size
        to 0 will make the buffer unlimited in size.

        **QNetworkReply**  will try to stop reading from the network once this
        buffer is full (i.e., **bytesAvailable** () returns **size** or more),
        thus causing the download to throttle down as well. If the buffer is not
        limited in size, **QNetworkReply**  will try to download as fast as
        possible from the network.

        Unlike **QAbstractSocket::setReadBufferSize** (), **QNetworkReply**
        cannot guarantee precision in the read buffer size. That is,
        **bytesAvailable** () can return more than **size**.

        **See also** **readBufferSize** ().
        """
        ...

    def readBufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#readBufferSize

        **qint64 QNetworkReply::readBufferSize() const**

        Returns the size of the read buffer, in bytes.

        **See also** **setReadBufferSize** ().
        """
        ...

    def isSequential(self) -> bool:
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#close

        **[override virtual] void QNetworkReply::close()**

        Reimplements: **QIODevice::close** ().

        Closes this device for reading. Unread data is discarded, but the
        network resources are not discarded until they are finished. In
        particular, if any upload is in progress, it will continue until it is
        done.

        The **finished** () signal is emitted when all operations are over and
        the network resources are freed.

        **See also** **abort** () and **finished** ().
        """
        ...

    def abort(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#abort

        **[pure virtual slot] void QNetworkReply::abort()**

        Aborts the operation immediately and close down any network connections
        still open. Uploads still in progress are also aborted.

        The **finished** () signal will also be emitted.

        **See also** **close** () and **finished** ().
        """
        ...

    @property
    def downloadProgress(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#downloadProgress

        **[signal] void QNetworkReply::downloadProgress(qint64 bytesReceived ,
        qint64 bytesTotal )**

        This signal is emitted to indicate the progress of the download part of
        this network request, if there's any. If there's no download associated
        with this request, this signal will be emitted once with 0 as the value
        of both **bytesReceived** and **bytesTotal**.

        The **bytesReceived** parameter indicates the number of bytes received,
        while **bytesTotal** indicates the total number of bytes expected to be
        downloaded. If the number of bytes to be downloaded is not known,
        **bytesTotal** will be -1.

        The download is finished when **bytesReceived** is equal to
        **bytesTotal**. At that time, **bytesTotal** will not be -1.

        Note that the values of both **bytesReceived** and **bytesTotal** may be
        different from **size** (), the total number of bytes obtained through
        **read** () or **readAll** (), or the value of the
        header(ContentLengthHeader). The reason for that is that there may be
        protocol overhead or the data may be compressed during the download.

        **See also** **uploadProgress** () and **bytesAvailable** ().
        """
        ...

    @property
    def encrypted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#encrypted

        **[signal, since 5.1] void QNetworkReply::encrypted()**

        This signal is emitted when an SSL/TLS session has successfully
        completed the initial handshake. At this point, no user data has been
        transmitted. The signal can be used to perform additional checks on the
        certificate chain, for example to notify users when the certificate for
        a website has changed. If the reply does not match the expected criteria
        then it should be aborted by calling **QNetworkReply::abort** () by a
        slot connected to this signal. The SSL configuration in use can be
        inspected using the **QNetworkReply::sslConfiguration** () method.

        Internally, **QNetworkAccessManager**  may open multiple connections to
        a server, in order to allow it process requests in parallel. These
        connections may be reused, which means that the encrypted() signal would
        not be emitted. This means that you are only guaranteed to receive this
        signal for the first connection to a site in the lifespan of the
        **QNetworkAccessManager** .

        This function was introduced in Qt 5.1.

        **See also** **QSslSocket::encrypted** () and
        **QNetworkAccessManager::encrypted** ().
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#errorOccurred

        **[signal, since 5.15] void
        QNetworkReply::errorOccurred(QNetworkReply::NetworkError code )**

        This signal is emitted when the reply detects an error in processing.
        The **finished** () signal will probably follow, indicating that the
        connection is over.

        The **code** parameter contains the code of the error that was detected.
        Call **errorString** () to obtain a textual representation of the error
        condition.

        **Note:** Do not delete the object in the slot connected to this signal.
        Use **deleteLater** ().

        This function was introduced in Qt 5.15.

        **See also** **error** () and **errorString** ().
        """
        ...

    @property
    def finished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#finished

        **[signal] void QNetworkReply::finished()**

        This signal is emitted when the reply has finished processing. After
        this signal is emitted, there will be no more updates to the reply's
        data or metadata.

        Unless **close** () or **abort** () have been called, the reply will be
        still be opened for reading, so the data can be retrieved by calls to
        **read** () or **readAll** (). In particular, if no calls to **read** ()
        were made as a result of **readyRead** (), a call to **readAll** () will
        retrieve the full contents in a **QByteArray** .

        This signal is emitted in tandem with
        **QNetworkAccessManager::finished** () where that signal's reply
        parameter is this object.

        **Note:** Do not delete the object in the slot connected to this signal.
        Use **deleteLater** ().

        You can also use **isFinished** () to check if a **QNetworkReply**  has
        finished even before you receive the finished() signal.

        **See also** **setFinished** (), **QNetworkAccessManager::finished** (),
        and **isFinished** ().
        """
        ...

    @property
    def metaDataChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#metaDataChanged

        **[signal] void QNetworkReply::metaDataChanged()**

        This signal is emitted whenever the metadata in this reply changes.
        metadata is any information that is not the content (data) itself,
        including the network headers. In the majority of cases, the metadata
        will be known fully by the time the first byte of data is received.
        However, it is possible to receive updates of headers or other metadata
        during the processing of the data.

        **See also** **header** (), **rawHeaderList** (), **rawHeader** (), and
        **hasRawHeader** ().
        """
        ...

    @property
    def preSharedKeyAuthenticationRequired(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#preSharedKeyAuthenticationRequ
        ired

        **[signal, since 5.5] void QNetworkReply::preSharedKeyAuthenticationRequ
        ired(QSslPreSharedKeyAuthenticator * authenticator )**

        This signal is emitted if the SSL/TLS handshake negotiates a PSK
        ciphersuite, and therefore a PSK authentication is then required.

        When using PSK, the client must send to the server a valid identity and
        a valid pre shared key, in order for the SSL handshake to continue.
        Applications can provide this information in a slot connected to this
        signal, by filling in the passed **authenticator** object according to
        their needs.

        **Note:** Ignoring this signal, or failing to provide the required
        credentials, will cause the handshake to fail, and therefore the
        connection to be aborted.

        **Note:** The **authenticator** object is owned by the reply and must
        not be deleted by the application.

        This function was introduced in Qt 5.5.

        **See also** **QSslPreSharedKeyAuthenticator** .
        """
        ...

    @property
    def redirectAllowed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#redirectAllowed

        **[signal, since 5.9] void QNetworkReply::redirectAllowed()**

        When client code handling the **redirected** () signal has verified the
        new URL, it emits this signal to allow the redirect to go ahead. This
        protocol applies to network requests whose redirects policy is set to
        **QNetworkRequest::UserVerifiedRedirectPolicy**

        This function was introduced in Qt 5.9.

        **See also** **QNetworkRequest::UserVerifiedRedirectPolicy** ,
        **QNetworkAccessManager::setRedirectPolicy** (), and
        **QNetworkRequest::RedirectPolicyAttribute** .
        """
        ...

    @property
    def redirected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#redirected

        **[signal, since 5.6] void QNetworkReply::redirected(const QUrl & url
        )**

        This signal is emitted if the **QNetworkRequest::ManualRedirectPolicy**
        was set in the request and the server responded with a 3xx status
        (specifically 301, 302, 303, 305, 307 or 308 status code) with a valid
        url in the location header, indicating a HTTP redirect. The **url**
        parameter contains the new redirect url as returned by the server in the
        location header.

        This function was introduced in Qt 5.6.

        **See also** **QNetworkRequest::RedirectPolicy** .
        """
        ...

    @property
    def sslErrors(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#sslErrors

        **[signal] void QNetworkReply::sslErrors(const QList<QSslError> & errors
        )**

        This signal is emitted if the SSL/TLS session encountered errors during
        the set up, including certificate verification errors. The **errors**
        parameter contains the list of errors.

        To indicate that the errors are not fatal and that the connection should
        proceed, the **ignoreSslErrors** () function should be called from the
        slot connected to this signal. If it is not called, the SSL session will
        be torn down before any data is exchanged (including the URL).

        This signal can be used to display an error message to the user
        indicating that security may be compromised and display the SSL settings
        (see **sslConfiguration** () to obtain it). If the user decides to
        proceed after analyzing the remote certificate, the slot should call
        **ignoreSslErrors** ().

        **See also** **QSslSocket::sslErrors** (),
        **QNetworkAccessManager::sslErrors** (), **sslConfiguration** (), and
        **ignoreSslErrors** ().
        """
        ...

    @property
    def uploadProgress(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnetworkreply.html#uploadProgress

        **[signal] void QNetworkReply::uploadProgress(qint64 bytesSent , qint64
        bytesTotal )**

        This signal is emitted to indicate the progress of the upload part of
        this network request, if there's any. If there's no upload associated
        with this request, this signal will not be emitted.

        The **bytesSent** parameter indicates the number of bytes uploaded,
        while **bytesTotal** indicates the total number of bytes to be uploaded.
        If the number of bytes to be uploaded could not be determined,
        **bytesTotal** will be -1.

        The upload is finished when **bytesSent** is equal to **bytesTotal**. At
        that time, **bytesTotal** will not be -1.

        **See also** **downloadProgress** ().
        """
        ...
